% Auto-generated chapter 29 for muslim
% Hadiths in this chapter: 70

\hadithdefcmd{muslim}{4398}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَابْنُ أَبِي عُمَرَ، - وَاللَّفْظُ لِيَحْيَى - قَالَ ابْنُ أَبِي عُمَرَ حَدَّثَنَا وَقَالَ الآخَرَانِ، أَخْبَرَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ عَمْرَةَ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَقْطَعُ السَّارِقَ فِي رُبْعِ دِينَارٍ فَصَاعِدًا\hadithno{4398}\hadithtrans{A'isha reported that Allah's Messenger (ﷺ) cut off the hand of a thief for a quarter of a dinar rid upwards}}
\hadithdefcmd{muslim}{4399}{وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَعَبْدُ بْنُ حُمَيْدٍ، قَالاَ أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، ح وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَخْبَرَنَا سُلَيْمَانُ بْنُ كَثِيرٍ، وَإِبْرَاهِيمُ بْنُ سَعْدٍ كُلُّهُمْ عَنِ الزُّهْرِيِّ، ‏.‏ بِمِثْلِهِ فِي هَذَا الإِسْنَادِ ‏.‏\hadithno{4399}\hadithtrans{This hadith has been transmitted on the authority of Zuhri}}
\hadithdefcmd{muslim}{4400}{وَحَدَّثَنِي أَبُو الطَّاهِرِ، وَحَرْمَلَةُ بْنُ يَحْيَى، وَحَدَّثَنَا الْوَلِيدُ بْنُ شُجَاعٍ، - وَاللَّفْظُ لِلْوَلِيدِ وَحَرْمَلَةَ - قَالُوا حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، وَعَمْرَةَ، عَنْ عَائِشَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تُقْطَعُ يَدُ السَّارِقِ إِلاَّ فِي رُبْعِ دِينَارٍ فَصَاعِدًا ‏"‏ ‏.‏\hadithno{4400}\hadithtrans{A'isha reported Allah's Messenger (ﷺ) as saying:The hand of a thief should not be cut off but for a quarter of a dinar and upwards}}
\hadithdefcmd{muslim}{4401}{وَحَدَّثَنِي أَبُو الطَّاهِرِ، وَهَارُونُ بْنُ سَعِيدٍ الأَيْلِيُّ، وَأَحْمَدُ بْنُ عِيسَى، - وَاللَّفْظُ لِهَارُونَ وَأَحْمَدَ - قَالَ أَبُو الطَّاهِرِ أَخْبَرَنَا وَقَالَ الآخَرَانِ، حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي مَخْرَمَةُ، عَنْ أَبِيهِ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، عَنْ عَمْرَةَ، أَنَّهَا سَمِعَتْ عَائِشَةَ، تُحَدِّثُ أَنَّهَا سَمِعَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ تُقْطَعُ الْيَدُ إِلاَّ فِي رُبْعِ دِينَارٍ فَمَا فَوْقَهُ ‏"‏ ‏.‏\hadithno{4401}\hadithtrans{A'isha reported:I heard Allah's Messenger (ﷺ) as saying: The hand (of a thief) should not be cut off but for a quarter of a dinar and what is above that}}
\hadithdefcmd{muslim}{4402}{حَدَّثَنِي بِشْرُ بْنُ الْحَكَمِ الْعَبْدِيُّ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، عَنْ يَزِيدَ بْنِ عَبْدِ اللَّهِ، بْنِ الْهَادِ عَنْ أَبِي بَكْرِ بْنِ مُحَمَّدٍ، عَنْ عَمْرَةَ، عَنْ عَائِشَةَ، أَنَّهَا سَمِعَتِ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ تُقْطَعُ يَدُ السَّارِقِ إِلاَّ فِي رُبْعِ دِينَارٍ فَصَاعِدًا ‏"‏ ‏.‏\hadithno{4402}\hadithtrans{A'isha reported that she heard Allah's Apostle (ﷺ) as saying:The hand of the thief may not be cut off but for a quarter of a dinar and upwards}}
\hadithdefcmd{muslim}{4403}{وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، وَإِسْحَاقُ بْنُ مَنْصُورٍ، جَمِيعًا عَنْ أَبِي عَامِرٍ الْعَقَدِيِّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ جَعْفَرٍ، - مِنْ وَلَدِ الْمِسْوَرِ بْنِ مَخْرَمَةَ - عَنْ يَزِيدَ بْنِ، عَبْدِ اللَّهِ بْنِ الْهَادِ بِهَذَا الإِسْنَادِ مِثْلَهُ ‏.‏\hadithno{4403}\hadithtrans{A hadith like this has been narrated on the authority of Yazid b. 'Abdullah b. al-Had with the same chain of transmitters}}
\hadithdefcmd{muslim}{4404}{وَحَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا حُمَيْدُ بْنُ عَبْدِ الرَّحْمَنِ الرُّؤَاسِيُّ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ لَمْ تُقْطَعْ يَدُ سَارِقٍ فِي عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي أَقَلَّ مِنْ ثَمَنِ الْمِجَنِّ حَجَفَةٍ أَوْ تُرْسٍ وَكِلاَهُمَا ذُو ثَمَنٍ ‏.‏\hadithno{4404}\hadithtrans{A'isha reported that during the lifetime of Allah's Messenger (ﷺ) the hand of the thief was not cut off for less than the price of a shield, iron coat or armour and both of them are valuable}}
\hadithdefcmd{muslim}{4405}{وَحَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، أَخْبَرَنَا عَبْدَةُ بْنُ سُلَيْمَانَ، وَحُمَيْدُ بْنُ عَبْدِ الرَّحْمَنِ، ح وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ الرَّحِيمِ بْنُ سُلَيْمَانَ، ح وَحَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو أُسَامَةَ، كُلُّهُمْ عَنْ هِشَامٍ، بِهَذَا الإِسْنَادِ ‏.‏ نَحْوَ حَدِيثِ ابْنِ نُمَيْرٍ عَنْ حُمَيْدِ بْنِ عَبْدِ الرَّحْمَنِ، الرُّؤَاسِيِّ وَفِي حَدِيثِ عَبْدِ الرَّحِيمِ وَأَبِي أُسَامَةَ وَهُوَ يَوْمَئِذٍ ذُو ثَمَنٍ ‏.‏\hadithno{4405}\hadithtrans{This hadith has been narrated on the authority of Hisham through another chain of transmitters, and in the hadith narrated by 'Abd al-Rahim and Abu Usama (the words are):" That (the shield) was valuable those days}}
\hadithdefcmd{muslim}{4406}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَطَعَ سَارِقًا فِي مِجَنٍّ قِيمَتُهُ ثَلاَثَةُ دَرَاهِمَ ‏.‏\hadithno{4406}\hadithtrans{Ibn 'Umar reported that Allah's Messenger (may peace upon him) cut off the hand of a thief (in case of the theft) of a shield the price of which was three dirhams}}
\hadithdefcmd{muslim}{4407}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، وَابْنُ، رُمْحٍ عَنِ اللَّيْثِ بْنِ سَعْدٍ، ح وَحَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، وَابْنُ الْمُثَنَّى قَالاَ حَدَّثَنَا يَحْيَى، وَهُوَ الْقَطَّانُ ح وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبِي ح، وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، كُلُّهُمْ عَنْ عُبَيْدِ اللَّهِ، ح وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا إِسْمَاعِيلُ يَعْنِي ابْنَ عُلَيَّةَ، ح وَحَدَّثَنَا أَبُو الرَّبِيعِ، وَأَبُو كَامِلٍ قَالاَ حَدَّثَنَا حَمَّادٌ، ح وَحَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا سُفْيَانُ، عَنْ أَيُّوبَ السَّخْتِيَانِيِّ، وَأَيُّوبَ، بْنِ مُوسَى وَإِسْمَاعِيلَ بْنِ أُمَيَّةَ ح. وَحَدَّثَنِي عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ الدَّارِمِيُّ، أَخْبَرَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا سُفْيَانُ، عَنْ أَيُّوبَ، وَإِسْمَاعِيلَ بْنِ أُمَيَّةَ، وَعُبَيْدِ اللَّهِ، وَمُوسَى بْنِ عُقْبَةَ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي إِسْمَاعِيلُ بْنُ أُمَيَّةَ، ح وَحَدَّثَنِي أَبُو الطَّاهِرِ، أَخْبَرَنَا ابْنُ وَهْبٍ، عَنْ حَنْظَلَةَ بْنِ أَبِي سُفْيَانَ الْجُمَحِيِّ، وَعُبَيْدِ اللَّهِ بْنِ عُمَرَ، وَمَالِكِ بْنِ أَنَسٍ، وَأُسَامَةَ، بْنِ زَيْدٍ اللَّيْثِيِّ كُلُّهُمْ عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ بِمِثْلِ حَدِيثِ يَحْيَى عَنْ مَالِكٍ غَيْرَ أَنَّ بَعْضَهُمْ قَالَ قِيمَتُهُ وَبَعْضُهُمْ قَالَ ثَمَنُهُ ثَلاَثَةُ دَرَاهِمَ ‏.‏\hadithno{4407}\hadithtrans{This hadith has been narrated on the authority of Ibn 'Umar through some other chains of transmitters but with a slight variation of words}}
\hadithdefcmd{muslim}{4408}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ قَالاَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَعَنَ اللَّهُ السَّارِقَ يَسْرِقُ الْبَيْضَةَ فَتُقْطَعُ يَدُهُ وَيَسْرِقُ الْحَبْلَ فَتُقْطَعُ يَدُهُ ‏"‏ ‏.‏\hadithno{4408}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:Let there be the curse of Allah upon the thief who steals an egg and his hand is cut off, and steals a rope and his hand is cut off}}
\hadithdefcmd{muslim}{4409}{حَدَّثَنَا عَمْرٌو النَّاقِدُ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَعَلِيُّ بْنُ خَشْرَمٍ، كُلُّهُمْ عَنْ عِيسَى، بْنِ يُونُسَ عَنِ الأَعْمَشِ، بِهَذَا الإِسْنَادِ ‏.‏ مِثْلَهُ غَيْرَ أَنَّهُ يَقُولُ ‏ "‏ إِنْ سَرَقَ حَبْلاً وَإِنْ سَرَقَ بَيْضَةً ‏"‏ ‏.‏\hadithno{4409}\hadithtrans{This hadith is narrated on the authority of A'mash with the same chain of transmitters with a slight variation of words}}
\hadithdefcmd{muslim}{4410}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، أَخْبَرَنَا اللَّيْثُ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، عَنَ عَائِشَةَ، أَنَّ قُرَيْشًا، أَهَمَّهُمْ شَأْنُ الْمَرْأَةِ الْمَخْزُومِيَّةِ الَّتِي سَرَقَتْ فَقَالُوا مَنْ يُكَلِّمُ فِيهَا رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالُوا وَمَنْ يَجْتَرِئُ عَلَيْهِ إِلاَّ أُسَامَةُ حِبُّ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ فَكَلَّمَهُ أُسَامَةُ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَتَشْفَعُ فِي حَدٍّ مِنْ حُدُودِ اللَّهِ ‏"‏ ‏.‏ ثُمَّ قَامَ فَاخْتَطَبَ فَقَالَ ‏"‏ أَيُّهَا النَّاسُ إِنَّمَا أَهْلَكَ الَّذِينَ قَبْلَكُمْ أَنَّهُمْ كَانُوا إِذَا سَرَقَ فِيهِمُ الشَّرِيفُ تَرَكُوهُ وَإِذَا سَرَقَ فِيهِمُ الضَّعِيفُ أَقَامُوا عَلَيْهِ الْحَدَّ وَايْمُ اللَّهِ لَوْ أَنَّ فَاطِمَةَ بِنْتَ مُحَمَّدٍ سَرَقَتْ لَقَطَعْتُ يَدَهَا ‏"‏ ‏.‏ وَفِي حَدِيثِ ابْنِ رُمْحٍ ‏"‏ إِنَّمَا هَلَكَ الَّذِينَ مِنْ قَبْلِكُمْ ‏"‏ ‏.‏\hadithno{4410}\hadithtrans{A'isha reported that the Quraish had been anxious about the Makhzumi woman who had committed theft, and said:Who will speak to Allah's Messenger (ﷺ) about her? They said: Who dare it, but Usama, the loved one of Allah's Messenger (ﷺ)? So Usama spoke to him. Thereupon Allah's Messenger (ﷺ) said: Do you intercede regarding one of the punishments prescribed by Allah? He then stood up and addressed (people) saying: O people, those who have gone before you were destroyed, because if any one of high rank committed theft amongst them, they spared him; and it anyone of low rank committed theft, they inflicted the prescribed punishment upon him. By Allah, if Fatima, daughter of Muhammad, were to steal, I would have her hand cut off. In the hadith transmitted on the authority of Ibn Rumh (the words are):" Verily those before you perished}}
\hadithdefcmd{muslim}{4411}{وَحَدَّثَنِي أَبُو الطَّاهِرِ، وَحَرْمَلَةُ بْنُ يَحْيَى، - وَاللَّفْظُ لِحَرْمَلَةَ - قَالاَ أَخْبَرَنَا ابْنُ، وَهْبٍ قَالَ أَخْبَرَنِي يُونُسُ بْنُ يَزِيدَ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي عُرْوَةُ بْنُ الزُّبَيْرِ، عَنْ عَائِشَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّ قُرَيْشًا أَهَمَّهُمْ شَأْنُ الْمَرْأَةِ الَّتِي سَرَقَتْ فِي عَهْدِ النَّبِيِّ صلى الله عليه وسلم فِي غَزْوَةِ الْفَتْحِ فَقَالُوا مَنْ يُكَلِّمُ فِيهَا رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالُوا وَمَنْ يَجْتَرِئُ عَلَيْهِ إِلاَّ أُسَامَةُ بْنُ زَيْدٍ حِبُّ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ فَأُتِيَ بِهَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَكَلَّمَهُ فِيهَا أُسَامَةُ بْنُ زَيْدٍ فَتَلَوَّنَ وَجْهُ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ أَتَشْفَعُ فِي حَدٍّ مِنْ حُدُودِ اللَّهِ ‏"‏ ‏.‏ فَقَالَ لَهُ أُسَامَةُ اسْتَغْفِرْ لِي يَا رَسُولَ اللَّهِ ‏.‏ فَلَمَّا كَانَ الْعَشِيُّ قَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَاخْتَطَبَ فَأَثْنَى عَلَى اللَّهِ بِمَا هُوَ أَهْلُهُ ثُمَّ قَالَ ‏"‏ أَمَّا بَعْدُ فَإِنَّمَا أَهْلَكَ الَّذِينَ مِنْ قَبْلِكُمْ أَنَّهُمْ كَانُوا إِذَا سَرَقَ فِيهِمُ الشَّرِيفُ تَرَكُوهُ وَإِذَا سَرَقَ فِيهِمُ الضَّعِيفُ أَقَامُوا عَلَيْهِ الْحَدَّ وَإِنِّي وَالَّذِي نَفْسِي بِيَدِهِ لَوْ أَنَّ فَاطِمَةَ بِنْتَ مُحَمَّدٍ سَرَقَتْ لَقَطَعْتُ يَدَهَا ‏"‏ ‏.‏ ثُمَّ أَمَرَ بِتِلْكَ الْمَرْأَةِ الَّتِي سَرَقَتْ فَقُطِعَتْ يَدُهَا ‏.‏ قَالَ يُونُسُ قَالَ ابْنُ شِهَابٍ قَالَ عُرْوَةُ قَالَتْ عَائِشَةُ فَحَسُنَتْ تَوْبَتُهَا بَعْدُ وَتَزَوَّجَتْ وَكَانَتْ تَأْتِينِي بَعْدَ ذَلِكَ فَأَرْفَعُ حَاجَتَهَا إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{4411}\hadithtrans{A'isha, the wife of Allah's Apostle (ﷺ), reported that the Quraish were concerned about the woman who had committed theft during the lifetime of Allah's Apostle (ﷺ), in the expedition of Victory (of Mecca). They said:Who would speak to Allah's Messenger (ﷺ) about her? They (again) said: Who can dare do this but Usama b. Zaid, the loved one of Allah's Messenger (ﷺ)? She was brought to Allah's Messenger (ﷺ) and Usama b. Zaid spoke about her to him (interceded on her behalf). The color of the face of Allah's Messenger (ﷺ) changed, and he said: Do you intercede in one of the prescribed punishments of Allah? He (Usama) said: 'Messenger of Allah, seek forgiveness for me.' When it was dusk. Allah's Messenger (ﷺ) stood up and gave an address. He (first) glorified Allah as He deserves, and then said: Now to our topic. This (injustice) destroyed those before you that when any one of (high) rank committed theft among them, they spared him, and when any weak one among them committed theft, they inflicted the prescribed punishment upon him. By Him in Whose Hand is my life, even if Fatima daughter of Muhammad were to commit theft, I would have cut off her hand. He (the Holy Prophet) then commanded about that woman who had committed theft, and her hand was cut off. `A'isha (further) said: Hers was a good repentance, and she later on married and used to come to me after that, and I conveyed her needs (and problems) to Allah's Messenger (ﷺ)}}
\hadithdefcmd{muslim}{4412}{وَحَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتْ كَانَتِ امْرَأَةٌ مَخْزُومِيَّةٌ تَسْتَعِيرُ الْمَتَاعَ وَتَجْحَدُهُ فَأَمَرَ النَّبِيُّ صلى الله عليه وسلم أَنْ تُقْطَعَ يَدُهَا فَأَتَى أَهْلُهَا أُسَامَةَ بْنَ زَيْدٍ فَكَلَّمُوهُ فَكَلَّمَ رَسُولَ اللَّهِ صلى الله عليه وسلم فِيهَا ‏.‏ ثُمَّ ذَكَرَ نَحْوَ حَدِيثِ اللَّيْثِ وَيُونُسَ ‏.‏\hadithno{4412}\hadithtrans{A'isha reported that a woman from the tribe of Makhzum used to borrow things (from people) and then denied (having taken them). Allah's Apostle (ﷺ) commanded her hand to be cut off. Her relatives came to Usama b. Zaid and spoke to him (requesting him to intercede on her behalf). He spoke to Allah's Messenger (ﷺ) about her. The rest of the hadith is the same}}
\hadithdefcmd{muslim}{4413}{وَحَدَّثَنِي سَلَمَةُ بْنُ شَبِيبٍ، حَدَّثَنَا الْحَسَنُ بْنُ أَعْيَنَ، حَدَّثَنَا مَعْقِلٌ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، أَنَّ امْرَأَةً، مِنْ بَنِي مَخْزُومٍ سَرَقَتْ فَأُتِيَ بِهَا النَّبِيُّ صلى الله عليه وسلم فَعَاذَتْ بِأُمِّ سَلَمَةَ زَوْجِ النَّبِيِّ صلى الله عليه وسلم فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ وَاللَّهِ لَوْ كَانَتْ فَاطِمَةُ لَقَطَعْتُ يَدَهَا ‏"‏ ‏.‏ فَقُطِعَتْ ‏.‏\hadithno{4413}\hadithtrans{Jaibir reported that a woman from the tribe of Makhzum committed theft. She was brought to Allah's Apostle (ﷺ) and she sought refuge (intercession) from Umm Salama, the wife of Allah's Apostle (ﷺ). Thereupon Allah's Apostle (ﷺ) said:By Allah, even if she were Fatima, I would have her hand cut off. And thus her hand was cut off}}
\hadithdefcmd{muslim}{4414}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى التَّمِيمِيُّ، أَخْبَرَنَا هُشَيْمٌ، عَنْ مَنْصُورٍ، عَنِ الْحَسَنِ، عَنْ حِطَّانَ، بْنِ عَبْدِ اللَّهِ الرَّقَاشِيِّ عَنْ عُبَادَةَ بْنِ الصَّامِتِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ خُذُوا عَنِّي خُذُوا عَنِّي قَدْ جَعَلَ اللَّهُ لَهُنَّ سَبِيلاً الْبِكْرُ بِالْبِكْرِ جَلْدُ مِائَةٍ وَنَفْىُ سَنَةٍ وَالثَّيِّبُ بِالثَّيِّبِ جَلْدُ مِائَةٍ وَالرَّجْمُ ‏"‏ ‏.‏\hadithno{4414}\hadithtrans{Ubada b. as-Samit reported:Allah's Messenger (ﷺ) as saying: Receive (teaching) from me, receive (teaching) from me. Allah has ordained a way for those (women). When an unmarried male commits adultery with an unmarried female (they should receive) one hundred lashes and banishment for one year. And in case of married male committing adultery with a married female, they shall receive one hundred lashes and be stoned to death}}
\hadithdefcmd{muslim}{4415}{وَحَدَّثَنَا عَمْرٌو النَّاقِدُ، حَدَّثَنَا هُشَيْمٌ، أَخْبَرَنَا مَنْصُورٌ، بِهَذَا الإِسْنَادِ مِثْلَهُ ‏.‏\hadithno{4415}\hadithtrans{The above hadith is likewise narrated through another chain of transmitters}}
\hadithdefcmd{muslim}{4416}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ جَمِيعًا عَنْ عَبْدِ الأَعْلَى، قَالَ ابْنُ الْمُثَنَّى حَدَّثَنَا عَبْدُ الأَعْلَى، حَدَّثَنَا سَعِيدٌ، عَنْ قَتَادَةَ، عَنِ الْحَسَنِ، عَنْ حِطَّانَ بْنِ عَبْدِ اللَّهِ الرَّقَاشِيِّ، عَنْ عُبَادَةَ بْنِ الصَّامِتِ، قَالَ كَانَ نَبِيُّ اللَّهِ صلى الله عليه وسلم إِذَا أُنْزِلَ عَلَيْهِ كُرِبَ لِذَلِكَ وَتَرَبَّدَ لَهُ وَجْهُهُ - قَالَ - فَأُنْزِلَ عَلَيْهِ ذَاتَ يَوْمٍ فَلُقِيَ كَذَلِكَ فَلَمَّا سُرِّيَ عَنْهُ قَالَ ‏ "‏ خُذُوا عَنِّي فَقَدْ جَعَلَ اللَّهُ لَهُنَّ سَبِيلاً الثَّيِّبُ بِالثَّيِّبِ وَالْبِكْرُ بِالْبِكْرِ الثَّيِّبُ جَلْدُ مِائَةٍ ثُمَّ رَجْمٌ بِالْحِجَارَةِ وَالْبِكْرُ جَلْدُ مِائَةٍ ثُمَّ نَفْىُ سَنَةٍ ‏"‏ ‏.‏\hadithno{4416}\hadithtrans{Ubada b. as-Samit reported that whenever Allah's Apostle (ﷺ) received revelation, he felt its rigour and the complexion of his face changed. One day revelation descended upon him, he felt the same rigour. When it was over and he felt relief, he said:Take from me. Verily Allah has ordained a way for them (the women who commit fornication),: (When) a married man (commits adultery) with a married woman, and an unmarried male with an unmarried woman, then in case of married (persons) there is (a punishment) of one hundred lashes and then stoning (to death). And in case of unmarried persons, (the punishment) is one hundred lashes and exile for one year}}
\hadithdefcmd{muslim}{4417}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُعَاذُ بْنُ هِشَامٍ، حَدَّثَنِي أَبِي كِلاَهُمَا، عَنْ قَتَادَةَ، بِهَذَا الإِسْنَادِ ‏.‏ غَيْرَ أَنَّ فِي، حَدِيثِهِمَا ‏ "‏ الْبِكْرُ يُجْلَدُ وَيُنْفَى وَالثَّيِّبُ يُجْلَدُ وَيُرْجَمُ ‏"‏ ‏.‏ لاَ يَذْكُرَانِ سَنَةً وَلاَ مِائَةً ‏\hadithno{4417}\hadithtrans{This hadith has been reported on the authority of Qatada with the same chain of transmitters except with this variation that the unmarried is to be lashed and exiled, and the married one is to be lashed and stoned. There is neither any mention of one year nor that of one hundred}}
\hadithdefcmd{muslim}{4418}{حَدَّثَنِي أَبُو الطَّاهِرِ، وَحَرْمَلَةُ بْنُ يَحْيَى، قَالاَ حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي عُبَيْدُ اللَّهِ بْنُ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، أَنَّهُ سَمِعَ عَبْدَ اللَّهِ بْنَ عَبَّاسٍ، يَقُولُ قَالَ عُمَرُ بْنُ الْخَطَّابِ وَهُوَ جَالِسٌ عَلَى مِنْبَرِ رَسُولِ اللَّهِ صلى الله عليه وسلم إِنَّ اللَّهَ قَدْ بَعَثَ مُحَمَّدًا صلى الله عليه وسلم بِالْحَقِّ وَأَنْزَلَ عَلَيْهِ الْكِتَابَ فَكَانَ مِمَّا أُنْزِلَ عَلَيْهِ آيَةُ الرَّجْمِ قَرَأْنَاهَا وَوَعَيْنَاهَا وَعَقَلْنَاهَا فَرَجَمَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَرَجَمْنَا بَعْدَهُ فَأَخْشَى إِنْ طَالَ بِالنَّاسِ زَمَانٌ أَنْ يَقُولَ قَائِلٌ مَا نَجِدُ الرَّجْمَ فِي كِتَابِ اللَّهِ فَيَضِلُّوا بِتَرْكِ فَرِيضَةٍ أَنْزَلَهَا اللَّهُ وَإِنَّ الرَّجْمَ فِي كِتَابِ اللَّهِ حَقٌّ عَلَى مَنْ زَنَى إِذَا أَحْصَنَ مِنَ الرِّجَالِ وَالنِّسَاءِ إِذَا قَامَتِ الْبَيِّنَةُ أَوْ كَانَ الْحَبَلُ أَوْ الاِعْتِرَافُ ‏.‏\hadithno{4418}\hadithtrans{Abdullah b. 'Abbas reported that 'Umar b. Khattab sat on the pulpit of Allah's Messenger (ﷺ) and said:Verily Allah sent Muhammad (ﷺ) with truth and He sent down the Book upon him, and the verse of stoning was included in what was sent down to him. We recited it, retained it in our memory and understood it. Allah's Messenger (ﷺ) awarded the punishment of stoning to death (to the married adulterer and adulteress) and, after him, we also awarded the punishment of stoning, I am afraid that with the lapse of time, the people (may forget it) and may say: We do not find the punishment of stoning in the Book of Allah, and thus go astray by abandoning this duty prescribed by Allah. Stoning is a duty laid down in Allah's Book for married men and women who commit adultery when proof is established, or it there is pregnancy, or a confession}}
\hadithdefcmd{muslim}{4419}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَزُهَيْرُ بْنُ حَرْبٍ، وَابْنُ أَبِي عُمَرَ، قَالُوا حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، بِهَذَا الإِسْنَادِ ‏.‏\hadithno{4419}\hadithtrans{This hadith has been narrated on the authority of Zuhri with the same chain of transmitters}}
\hadithdefcmd{muslim}{4420}{وَحَدَّثَنِي عَبْدُ الْمَلِكِ بْنُ شُعَيْبِ بْنِ اللَّيْثِ بْنِ سَعْدٍ، حَدَّثَنِي أَبِي، عَنْ جَدِّي، قَالَ حَدَّثَنِي عُقَيْلٌ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ، وَسَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّهُ قَالَ أَتَى رَجُلٌ مِنَ الْمُسْلِمِينَ رَسُولَ اللَّهِ صلى الله عليه وسلم وَهُوَ فِي الْمَسْجِدِ فَنَادَاهُ فَقَالَ يَا رَسُولَ اللَّهِ إِنِّي زَنَيْتُ ‏.‏ فَأَعْرَضَ عَنْهُ فَتَنَحَّى تِلْقَاءَ وَجْهِهِ فَقَالَ لَهُ يَا رَسُولَ اللَّهِ إِنِّي زَنَيْتُ ‏.‏ فَأَعْرَضَ عَنْهُ حَتَّى ثَنَى ذَلِكَ عَلَيْهِ أَرْبَعَ مَرَّاتٍ فَلَمَّا شَهِدَ عَلَى نَفْسِهِ أَرْبَعَ شَهَادَاتٍ دَعَاهُ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ أَبِكَ جُنُونٌ ‏"‏ ‏.‏ قَالَ لاَ ‏.‏ قَالَ ‏"‏ فَهَلْ أَحْصَنْتَ ‏"‏ ‏.‏ قَالَ نَعَمْ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ اذْهَبُوا بِهِ فَارْجُمُوهُ ‏"‏ ‏.‏\hadithno{4420}\hadithtrans{Abu Huraira reported that a person from amongst the Muslims came to Allah's Messenger (ﷺ) while he was in the mosque. He called him saying:Allah's Messenger. I have committed adultery. He (the Holy Prophet) turned away from him, He (again) came round facing him and said to him: Allah's Messenger, I have committed adultery. He (the Holy Prophet) turned away until he did that four times, and as he testified four times against his own self, Allah's Messenger (ﷺ) called him and said: Are you mad? He said: No. He (again) said: Are you married? He said: Yes. Thereupon Allah's Messenger (ﷺ) said: Take him and stone him}}
\hadithdefcmd{muslim}{4421}{قَالَ ابْنُ شِهَابٍ فَأَخْبَرَنِي مَنْ، سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ، يَقُولُ فَكُنْتُ فِيمَنْ رَجَمَهُ فَرَجَمْنَاهُ بِالْمُصَلَّى فَلَمَّا أَذْلَقَتْهُ الْحِجَارَةُ هَرَبَ فَأَدْرَكْنَاهُ بِالْحَرَّةِ فَرَجَمْنَاهُ ‏.‏\hadithno{4421}\hadithtrans{Ibn Shihab (one of the narrators) said:One who had heard Jabir b. 'Abdullah saying this informed me thus: I was one of those who stoned him. We stoned him at the place of prayer (either that of 'Id or a funeral). When the stones hurt him, he ran away. We caught him in the Harra and stoned him (to death)}}
\hadithdefcmd{muslim}{4422}{وَرَوَاهُ اللَّيْثُ أَيْضًا عَنْ عَبْدِ الرَّحْمَنِ بْنِ خَالِدِ بْنِ مُسَافِرٍ، عَنِ ابْنِ شِهَابٍ، بِهَذَا الإِسْنَادِ ‏.‏ مِثْلَهُ ‏.‏ وَحَدَّثَنِيهِ عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ الدَّارِمِيُّ، حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، بِهَذَا الإِسْنَادِ أَيْضًا وَفِي حَدِيثِهِمَا جَمِيعًا قَالَ ابْنُ شِهَابٍ أَخْبَرَنِي مَنْ سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ كَمَا ذَكَرَ عُقَيْلٌ ‏.‏\hadithno{4422}\hadithtrans{This hadith has been narrated through another chain of transmitters}}
\hadithdefcmd{muslim}{4423}{وَحَدَّثَنِي أَبُو الطَّاهِرِ، وَحَرْمَلَةُ بْنُ يَحْيَى، قَالاَ أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، ح وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، وَابْنُ، جُرَيْجٍ كُلُّهُمْ عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ نَحْوَ رِوَايَةِ عُقَيْلٍ عَنِ الزُّهْرِيِّ عَنْ سَعِيدٍ وَأَبِي سَلَمَةَ عَنْ أَبِي هُرَيْرَةَ ‏.‏\hadithno{4423}\hadithtrans{This hadith has been narrated on the authority of Abu Huraira through other chains of transmitters}}
\hadithdefcmd{muslim}{4424}{وَحَدَّثَنِي أَبُو كَامِلٍ، فُضَيْلُ بْنُ حُسَيْنٍ الْجَحْدَرِيُّ حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ سِمَاكِ بْنِ، حَرْبٍ عَنْ جَابِرِ بْنِ سَمُرَةَ، قَالَ رَأَيْتُ مَاعِزَ بْنَ مَالِكٍ حِينَ جِيءَ بِهِ إِلَى النَّبِيِّ صلى الله عليه وسلم رَجُلٌ قَصِيرٌ أَعْضَلُ لَيْسَ عَلَيْهِ رِدَاءٌ فَشَهِدَ عَلَى نَفْسِهِ أَرْبَعَ مَرَّاتٍ أَنَّهُ زَنَى فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ فَلَعَلَّكَ ‏"‏ ‏.‏ قَالَ لاَ وَاللَّهِ إِنَّهُ قَدْ زَنَى الأَخِرُ - قَالَ - فَرَجَمَهُ ثُمَّ خَطَبَ فَقَالَ ‏"‏ أَلاَ كُلَّمَا نَفَرْنَا غَازِينَ فِي سَبِيلِ اللَّهِ خَلَفَ أَحَدُهُمْ لَهُ نَبِيبٌ كَنَبِيبِ التَّيْسِ يَمْنَحُ أَحَدُهُمُ الْكُثْبَةَ أَمَا وَاللَّهِ إِنْ يُمْكِنِّي مِنْ أَحَدِهِمْ لأُنَكِّلَنَّهُ عَنْهُ ‏"‏ ‏.‏\hadithno{4424}\hadithtrans{Jabir b. Samura reported:As he was being brought to Allah's Apostle (ﷺ) I saw Ma'iz b. Malik-a short-statured person with strong sinews, having no cloak around him. He bore witness against his own self four times that he had committed adultery, whereupon Allah's Messenger (ﷺ) said: Perhaps (you kissed her or embraced her). He said: No. by God, one deviating (from the path of virtue) has committed adultery. He then got him stoned (to death), and then delivered the address: Behold, as we set out for Jihad in the cause of Allah, one of you lagged behind and shrieked like the bleating of a male goat, and gave a small quantity of milk. By Allah, in case I get hold of him, I shall certainly punish him}}
\hadithdefcmd{muslim}{4425}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ - وَاللَّفْظُ لاِبْنِ الْمُثَنَّى - قَالاَ حَدَّثَنَا مُحَمَّدُ، بْنُ جَعْفَرٍ حَدَّثَنَا شُعْبَةُ، عَنْ سِمَاكِ بْنِ حَرْبٍ، قَالَ سَمِعْتُ جَابِرَ بْنَ سَمُرَةَ، يَقُولُ أُتِيَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِرَجُلٍ قَصِيرٍ أَشْعَثَ ذِي عَضَلاَتٍ عَلَيْهِ إِزَارٌ وَقَدْ زَنَى فَرَدَّهُ مَرَّتَيْنِ ثُمَّ أَمَرَ بِهِ فَرُجِمَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ كُلَّمَا نَفَرْنَا غَازِينَ فِي سَبِيلِ اللَّهِ تَخَلَّفَ أَحَدُكُمْ يَنِبُّ نَبِيبَ التَّيْسِ يَمْنَحُ إِحْدَاهُنَّ الْكُثْبَةَ إِنَّ اللَّهَ لاَ يُمْكِنِّي مِنْ أَحَدٍ مِنْهُمْ إِلاَّ جَعَلْتُهُ نَكَالاً ‏"‏ ‏.‏ أَوْ نَكَّلْتُهُ ‏.‏ قَالَ فَحَدَّثْتُهُ سَعِيدَ بْنَ جُبَيْرٍ فَقَالَ إِنَّهُ رَدَّهُ أَرْبَعَ مَرَّاتٍ ‏.‏\hadithno{4425}\hadithtrans{Jabir b. Samura reported that there was brought to Allah's Messenger (ﷺ) a short-statured person with thick uncombed hair, muscular body, having a mantle around him and he had committed adultery. He turned him away twice and then made pronouncement about him and he was stoned. Then Allah's Messenger (ﷺ) said:We set out for Jihad in the cause of Allah and one of you lagged behind and shrieked like the bleating of a male goat and one of then (goats' gave a small quantity of milk. In case Allah gives me power over one of them, I will punish him (in such a way that it may have a deterrent effect upon others). In another narration transmitted on the authority of Sa'id b Jubair (the words are), that He (the Holy Prophet) turned him away four times}}
\hadithdefcmd{muslim}{4426}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا شَبَابَةُ، ح وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا أَبُو عَامِرٍ الْعَقَدِيُّ، كِلاَهُمَا عَنْ شُعْبَةَ، عَنْ سِمَاكٍ، عَنْ جَابِرِ بْنِ سَمُرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ نَحْوَ حَدِيثِ ابْنِ جَعْفَرٍ وَوَافَقَهُ شَبَابَةُ عَلَى قَوْلِهِ فَرَدَّهُ مَرَّتَيْنِ ‏.‏ وَفِي حَدِيثِ أَبِي عَامِرٍ فَرَدَّهُ مَرَّتَيْنِ أَوْ ثَلاَثًا ‏.‏\hadithno{4426}\hadithtrans{This hadith has been narrated on the authority of Jabir b. Samura through another chain of transmitters with the difference that along with the mentioning (of the fact) that he (the Holy Prophet) turned him away twice, or thrice}}
\hadithdefcmd{muslim}{4427}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، وَأَبُو كَامِلٍ الْجَحْدَرِيُّ - وَاللَّفْظُ لِقُتَيْبَةَ - قَالاَ حَدَّثَنَا أَبُو عَوَانَةَ عَنْ سِمَاكٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ لِمَاعِزِ بْنِ مَالِكٍ ‏"‏ أَحَقٌّ مَا بَلَغَنِي عَنْكَ ‏"‏ ‏.‏ قَالَ وَمَا بَلَغَكَ عَنِّي قَالَ ‏"‏ بَلَغَنِي أَنَّكَ وَقَعْتَ بِجَارِيَةِ آلِ فُلاَنٍ ‏"‏ ‏.‏ قَالَ نَعَمْ ‏.‏ قَالَ فَشَهِدَ أَرْبَعَ شَهَادَاتٍ ‏.‏ ثُمَّ أَمَرَ بِهِ فَرُجِمَ ‏.‏\hadithno{4427}\hadithtrans{Ibn Abbas reported that Allah's Apostle (ﷺ) said to Ma'iz b. Malik:Is it true what has reached me about you? He said: What has reached you about me? He said: It has reached me that you have committed (adultery) with the slave-girl of so and so? He said: Yes. He (the narrator) said: He testified four times. He (the Holy Prophet) then made pronouncement about him and he was stoned (to death)}}
\hadithdefcmd{muslim}{4428}{حَدَّثَنِي مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنِي عَبْدُ الأَعْلَى، حَدَّثَنَا دَاوُدُ، عَنْ أَبِي نَضْرَةَ، عَنْ أَبِي، سَعِيدٍ أَنَّ رَجُلاً، مِنْ أَسْلَمَ يُقَالُ لَهُ مَاعِزُ بْنُ مَالِكٍ أَتَى رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ إِنِّي أَصَبْتُ فَاحِشَةً فَأَقِمْهُ عَلَىَّ ‏.‏ فَرَدَّهُ النَّبِيُّ صلى الله عليه وسلم مِرَارًا قَالَ ثُمَّ سَأَلَ قَوْمَهُ فَقَالُوا مَا نَعْلَمُ بِهِ بَأْسًا إِلاَّ أَنَّهُ أَصَابَ شَيْئًا يَرَى أَنَّهُ لاَ يُخْرِجُهُ مِنْهُ إِلاَّ أَنْ يُقَامَ فِيهِ الْحَدُّ - قَالَ - فَرَجَعَ إِلَى النَّبِيِّ صلى الله عليه وسلم فَأَمَرَنَا أَنْ نَرْجُمَهُ - قَالَ - فَانْطَلَقْنَا بِهِ إِلَى بَقِيعِ الْغَرْقَدِ - قَالَ - فَمَا أَوْثَقْنَاهُ وَلاَ حَفَرْنَا لَهُ - قَالَ - فَرَمَيْنَاهُ بِالْعَظْمِ وَالْمَدَرِ وَالْخَزَفِ - قَالَ - فَاشْتَدَّ فَاشْتَدَدْنَا خَلْفَهُ حَتَّى أَتَى عُرْضَ الْحَرَّةِ فَانْتَصَبَ لَنَا فَرَمَيْنَاهُ بِجَلاَمِيدِ الْحَرَّةِ - يَعْنِي الْحِجَارَةَ - حَتَّى سَكَتَ - قَالَ - ثُمَّ قَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم خَطِيبًا مِنَ الْعَشِيِّ فَقَالَ ‏ "‏ أَوَكُلَّمَا انْطَلَقْنَا غُزَاةً فِي سَبِيلِ اللَّهِ تَخَلَّفَ رَجُلٌ فِي عِيَالِنَا لَهُ نَبِيبٌ كَنَبِيبِ التَّيْسِ عَلَىَّ أَنْ لاَ أُوتَى بِرَجُلٍ فَعَلَ ذَلِكَ إِلاَّ نَكَّلْتُ بِهِ ‏"‏ ‏.‏ قَالَ فَمَا اسْتَغْفَرَ لَهُ وَلاَ سَبَّهُ ‏.‏\hadithno{4428}\hadithtrans{Abu Sa'id reported that a person belonging to the clan of Aslam, who was called Ma, iz b. Malik, came to Allah's Messenger (ﷺ) and said:I have committed immorality (adultery), so inflict punishment upon me. Allah's Apostle (ﷺ) turned him away again and again. He then asked his people (about the state of his mind). They said: We do not know of any ailment of his except that he has committed something about which he thinks that he would not be able to relieve himself of its burden but with the Hadd being imposed upon him. He (Ma'iz) came back to Allah's Apostle (ﷺ) and he commanded us to stone him. We took him to the Baqi' al-Gharqad (the graveyard of Medina). We neither tied him nor dug any ditch for him. We attacked him with bones, with clods and pebbles. He ran away and we ran after him until he came upon the ston ground (al-Harra) and stopped there and we stoned him with heavy stones of the Harra until he became motionless (lie died). He (the Holy Prophet) then addressed (us) in the evening saying Whenever we set forth on an expedition in the cause of Allah, some one of those connected with us shrieked (under the pressure of sexual lust) as the bleating of a male goat. It is essential that if a person having committed such a deed is brought to me, I should punish him. He neither begged forgiveness for him nor cursed him}}
\hadithdefcmd{muslim}{4429}{حَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنَا بَهْزٌ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا دَاوُدُ، بِهَذَا الإِسْنَادِ ‏.‏ مِثْلَ مَعْنَاهُ ‏.‏ وَقَالَ فِي الْحَدِيثِ فَقَامَ النَّبِيُّ صلى الله عليه وسلم مِنَ الْعَشِيِّ فَحَمِدَ اللَّهَ وَأَثْنَى عَلَيْهِ ثُمَّ قَالَ ‏"‏ أَمَّا بَعْدُ فَمَا بَالُ أَقْوَامٍ إِذَا غَزَوْنَا يَتَخَلَّفُ أَحَدُهُمْ عَنَّا لَهُ نَبِيبٌ كَنَبِيبِ التَّيْسِ ‏"‏ ‏.‏ وَلَمْ يَقُلْ ‏"‏ فِي عِيَالِنَا ‏"‏ ‏.‏\hadithno{4429}\hadithtrans{Dawud narrated the hadith with the same chain of transmitters (and the words are):Allah's Apostle (ﷺ) stood tip (to address the audience) in the evening and praised Allah, glorified Him and then said: What about the people, that as we set out on an expedition, one of you remained behind us and he shrieked like the bleating of a male goat? But he did not mention (these words): People connected with us}}
\hadithdefcmd{muslim}{4430}{وَحَدَّثَنَا سُرَيْجُ بْنُ يُونُسَ، حَدَّثَنَا يَحْيَى بْنُ زَكَرِيَّاءَ بْنِ أَبِي زَائِدَةَ، ح وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ حَدَّثَنَا مُعَاوِيَةُ بْنُ هِشَامٍ، حَدَّثَنَا سُفْيَانُ، كِلاَهُمَا عَنْ دَاوُدَ، بِهَذَا الإِسْنَادِ ‏.‏ بَعْضَ هَذَا الْحَدِيثِ ‏.‏ غَيْرَ أَنَّ فِي حَدِيثِ سُفْيَانَ فَاعْتَرَفَ بِالزِّنَى ثَلاَثَ مَرَّاتٍ ‏.‏\hadithno{4430}\hadithtrans{This hadith has been narrated on the authority of Dawud with the same chain of transmitters but with this variation that in the hadith narrated by Sufyan (the words are):" He made a confession of having committed adultery, thrice}}
\hadithdefcmd{muslim}{4431}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْعَلاَءِ الْهَمْدَانِيُّ، حَدَّثَنَا يَحْيَى بْنُ يَعْلَى، - وَهُوَ ابْنُ الْحَارِثِ الْمُحَارِبِيُّ - عَنْ غَيْلاَنَ، - وَهُوَ ابْنُ جَامِعٍ الْمُحَارِبِيُّ - عَنْ عَلْقَمَةَ بْنِ مَرْثَدٍ، عَنْ سُلَيْمَانَ، بْنِ بُرَيْدَةَ عَنْ أَبِيهِ، قَالَ جَاءَ مَاعِزُ بْنُ مَالِكٍ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ طَهِّرْنِي ‏.‏ فَقَالَ ‏"‏ وَيْحَكَ ارْجِعْ فَاسْتَغْفِرِ اللَّهَ وَتُبْ إِلَيْهِ ‏"‏ ‏.‏ قَالَ فَرَجَعَ غَيْرَ بَعِيدٍ ثُمَّ جَاءَ فَقَالَ يَا رَسُولَ اللَّهِ طَهِّرْنِي ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ وَيْحَكَ ارْجِعْ فَاسْتَغْفِرِ اللَّهَ وَتُبْ إِلَيْهِ ‏"‏ ‏.‏ قَالَ فَرَجَعَ غَيْرَ بَعِيدٍ ثُمَّ جَاءَ فَقَالَ يَا رَسُولَ اللَّهِ طَهِّرْنِي ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم مِثْلَ ذَلِكَ حَتَّى إِذَا كَانَتِ الرَّابِعَةُ قَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ فِيمَ أُطَهِّرُكَ ‏"‏ ‏.‏ فَقَالَ مِنَ الزِّنَى ‏.‏ فَسَأَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَبِهِ جُنُونٌ ‏"‏ ‏.‏ فَأُخْبِرَ أَنَّهُ لَيْسَ بِمَجْنُونٍ ‏.‏ فَقَالَ ‏"‏ أَشَرِبَ خَمْرًا ‏"‏ ‏.‏ فَقَامَ رَجُلٌ فَاسْتَنْكَهَهُ فَلَمْ يَجِدْ مِنْهُ رِيحَ خَمْرٍ ‏.‏ قَالَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَزَنَيْتَ ‏"‏ ‏.‏ فَقَالَ نَعَمْ ‏.‏ فَأَمَرَ بِهِ فَرُجِمَ فَكَانَ النَّاسُ فِيهِ فِرْقَتَيْنِ قَائِلٌ يَقُولُ لَقَدْ هَلَكَ لَقَدْ أَحَاطَتْ بِهِ خَطِيئَتُهُ وَقَائِلٌ يَقُولُ مَا تَوْبَةٌ أَفْضَلَ مِنْ تَوْبَةِ مَاعِزٍ أَنَّهُ جَاءَ إِلَى النَّبِيِّ صلى الله عليه وسلم فَوَضَعَ يَدَهُ فِي يَدِهِ ثُمَّ قَالَ اقْتُلْنِي بِالْحِجَارَةِ - قَالَ - فَلَبِثُوا بِذَلِكَ يَوْمَيْنِ أَوْ ثَلاَثَةً ثُمَّ جَاءَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَهُمْ جُلُوسٌ فَسَلَّمَ ثُمَّ جَلَسَ فَقَالَ ‏"‏ اسْتَغْفِرُوا لِمَاعِزِ بْنِ مَالِكٍ ‏"‏ ‏.‏ قَالَ فَقَالُوا غَفَرَ اللَّهُ لِمَاعِزِ بْنِ مَالِكٍ ‏.‏ - قَالَ - فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لَقَدْ تَابَ تَوْبَةً لَوْ قُسِمَتْ بَيْنَ أُمَّةٍ لَوَسِعَتْهُمْ ‏"‏ ‏.‏ قَالَ ثُمَّ جَاءَتْهُ امْرَأَةٌ مِنْ غَامِدٍ مِنَ الأَزْدِ فَقَالَتْ يَا رَسُولَ اللَّهِ طَهِّرْنِي ‏.‏ فَقَالَ ‏"‏ وَيْحَكِ ارْجِعِي فَاسْتَغْفِرِي اللَّهَ وَتُوبِي إِلَيْهِ ‏"‏ ‏.‏ فَقَالَتْ أَرَاكَ تُرِيدُ أَنْ تُرَدِّدَنِي كَمَا رَدَّدْتَ مَاعِزَ بْنَ مَالِكٍ ‏.‏ قَالَ ‏"‏ وَمَا ذَاكِ ‏"‏ ‏.‏ قَالَتْ إِنَّهَا حُبْلَى مِنَ الزِّنَا ‏.‏ فَقَالَ ‏"‏ آنْتِ ‏"‏ ‏.‏ قَالَتْ نَعَمْ ‏.‏ فَقَالَ لَهَا ‏"‏ حَتَّى تَضَعِي مَا فِي بَطْنِكِ ‏"‏ ‏.‏ قَالَ فَكَفَلَهَا رَجُلٌ مِنَ الأَنْصَارِ حَتَّى وَضَعَتْ قَالَ فَأَتَى النَّبِيَّ صلى الله عليه وسلم فَقَالَ قَدْ وَضَعَتِ الْغَامِدِيَّةُ ‏.‏ فَقَالَ ‏"‏ إِذًا لاَ نَرْجُمَهَا وَنَدَعَ وَلَدَهَا صَغِيرًا لَيْسَ لَهُ مَنْ يُرْضِعُهُ ‏"‏ ‏.‏ فَقَامَ رَجُلٌ مِنَ الأَنْصَارِ فَقَالَ إِلَىَّ رَضَاعُهُ يَا نَبِيَّ اللَّهِ ‏.‏ قَالَ فَرَجَمَهَا ‏.‏\hadithno{4431}\hadithtrans{Sulaiman b. Buraida reported on the authority of his father that Ma, iz b. Malik came to Allah's Apostle (ﷺ) and said to him:Messenger of Allah, purify me, whereupon he said: Woe be upon you, go back, ask forgiveness of Allah and turn to Him in repentance. He (the narrator) said that he went back not far, then came and said: Allah's Messenger, purify me. whereupon Allah's Messenger (ﷺ) said: Woe be upon you, go back and ask forgiveness of Allah and turn to Him in repentance. He (the narrator) said that he went back not far, when he came and said: Allah's Messenger, purify me. Allah's Apostle (ﷺ) said as he had said before. When it was the fourth time, Allah's Messenger (may, peace be upon him) said: From what am I to purify you? He said: From adultery, Allah's Messenger (ﷺ) asked if he had been mad. He was informed that he was not mad. He said: Has he drunk wine? A person stood up and smelt his breath but noticed no smell of wine. Thereupon Allah's Messenger (ﷺ) said: Have you committed adultery? He said: Yes. He made pronouncement about him and he was stoned to death. The people had been (divided) into two groups about him (Ma'iz). One of them said: He has been undone for his sins had encompassed him, whereas another said: There is no repentance more excellent than the repentance of Ma'iz, for he came to Allah's Apostle (ﷺ) and placing his hand in his (in the Holy Prophet's) hand said: Kill me with stones. (This controversy about Ma'iz) remained for two or three days. Then came Allah's Messenger (ﷺ) to them (his Companions) as they were sitting. He greeted them with salutation and then sat down and said: Ask forgiveness for Ma'iz b. Malik. They said: May Allah forgive Ma'iz b. Malik. Thereupon Allah's Messenger (ﷺ) said: He (Ma'iz) has made such a repentance that if that were to be divided among a people, it would have been enough for all of them. He (the narrator) said: Then a woman of Ghamid, a branch of Azd, came to him and said: Messenger of of Allah, purify me, whereupon he said: Woe be upon you; go back and beg forgiveness from Allah and turn to Him in repentance. She said: I find that you intend to send me back as you sent back Ma'iz. b. Malik. He (the Holy, Prophet) said: What has happened to you? She said that she had become pregnant as a result of fornication. He (the Holy Prophet) said: Is it you (who has done that)? She said: Yes. He (the Holy Prophet) said to her: (You will not be punished) until you deliver what is there in your womb. One of the Ansar became responsible for her until she was delivered (of the child). He (that Ansari) came to Allah's Apostle (ﷺ) and said the woman of Ghamid has given birth to a child. He (the Holy Prophet) said: In that case we shall not stone her and so leave her infant with none to suckle him. One of the Ansar got up and said: Allah's Apostle, let the responsibility of his suckling be upon me. She was then stoned to death}}
\hadithdefcmd{muslim}{4432}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ، اللَّهِ بْنِ نُمَيْرٍ - وَتَقَارَبَا فِي لَفْظِ الْحَدِيثِ - حَدَّثَنَا أَبِي، حَدَّثَنَا بَشِيرُ بْنُ الْمُهَاجِرِ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ بُرَيْدَةَ، عَنْ أَبِيهِ، أَنَّ مَاعِزَ بْنَ مَالِكٍ الأَسْلَمِيَّ، أَتَى رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ إِنِّي قَدْ ظَلَمْتُ نَفْسِي وَزَنَيْتُ وَإِنِّي أُرِيدُ أَنْ تُطَهِّرَنِي ‏.‏ فَرَدَّهُ فَلَمَّا كَانَ مِنَ الْغَدِ أَتَاهُ فَقَالَ يَا رَسُولَ اللَّهِ إِنِّي قَدْ زَنَيْتُ ‏.‏ فَرَدَّهُ الثَّانِيَةَ فَأَرْسَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِلَى قَوْمِهِ فَقَالَ ‏"‏ أَتَعْلَمُونَ بِعَقْلِهِ بَأْسًا تُنْكِرُونَ مِنْهُ شَيْئًا ‏"‏ ‏.‏ فَقَالُوا مَا نَعْلَمُهُ إِلاَّ وَفِيَّ الْعَقْلِ مِنْ صَالِحِينَا فِيمَا نُرَى فَأَتَاهُ الثَّالِثَةَ فَأَرْسَلَ إِلَيْهِمْ أَيْضًا فَسَأَلَ عَنْهُ فَأَخْبَرُوهُ أَنَّهُ لاَ بَأْسَ بِهِ وَلاَ بِعَقْلِهِ فَلَمَّا كَانَ الرَّابِعَةَ حَفَرَ لَهُ حُفْرَةً ثُمَّ أَمَرَ بِهِ فَرُجِمَ ‏.‏ قَالَ فَجَاءَتِ الْغَامِدِيَّةُ فَقَالَتْ يَا رَسُولَ اللَّهِ إِنِّي قَدْ زَنَيْتُ فَطَهِّرْنِي ‏.‏ وَإِنَّهُ رَدَّهَا فَلَمَّا كَانَ الْغَدُ قَالَتْ يَا رَسُولَ اللَّهِ لِمَ تَرُدُّنِي لَعَلَّكَ أَنْ تَرُدَّنِي كَمَا رَدَدْتَ مَاعِزًا فَوَاللَّهِ إِنِّي لَحُبْلَى ‏.‏ قَالَ ‏"‏ إِمَّا لاَ فَاذْهَبِي حَتَّى تَلِدِي ‏"‏ ‏.‏ فَلَمَّا وَلَدَتْ أَتَتْهُ بِالصَّبِيِّ فِي خِرْقَةٍ قَالَتْ هَذَا قَدْ وَلَدْتُهُ ‏.‏ قَالَ ‏"‏ اذْهَبِي فَأَرْضِعِيهِ حَتَّى تَفْطِمِيهِ ‏"‏ ‏.‏ فَلَمَّا فَطَمَتْهُ أَتَتْهُ بِالصَّبِيِّ فِي يَدِهِ كِسْرَةُ خُبْزٍ فَقَالَتْ هَذَا يَا نَبِيَّ اللَّهِ قَدْ فَطَمْتُهُ وَقَدْ أَكَلَ الطَّعَامَ ‏.‏ فَدَفَعَ الصَّبِيَّ إِلَى رَجُلٍ مِنَ الْمُسْلِمِينَ ثُمَّ أَمَرَ بِهَا فَحُفِرَ لَهَا إِلَى صَدْرِهَا وَأَمَرَ النَّاسَ فَرَجَمُوهَا فَيُقْبِلُ خَالِدُ بْنُ الْوَلِيدِ بِحَجَرٍ فَرَمَى رَأْسَهَا فَتَنَضَّحَ الدَّمُ عَلَى وَجْهِ خَالِدٍ فَسَبَّهَا فَسَمِعَ نَبِيُّ اللَّهِ صلى الله عليه وسلم سَبَّهُ إِيَّاهَا فَقَالَ ‏"‏ مَهْلاً يَا خَالِدُ فَوَالَّذِي نَفْسِي بِيَدِهِ لَقَدْ تَابَتْ تَوْبَةً لَوْ تَابَهَا صَاحِبُ مَكْسٍ لَغُفِرَ لَهُ ‏"‏ ‏.‏ ثُمَّ أَمَرَ بِهَا فَصَلَّى عَلَيْهَا وَدُفِنَتْ ‏.‏\hadithno{4432}\hadithtrans{Abdullah b. Buraida reported on the authority of his father that Ma'iz b. Malik al-Aslami came to Allah's Messenger (ﷺ) and said:Allah's Messenger, I have wronged myself; I have committed adultery and I earnestly desire that you should purify me. He turned him away. On the following day, he (Ma'iz) again came to him and said: Allah's Messenger, I have committed adultery. Allah's Messenger (ﷺ) turned him away for the second time, and sent him to his people saying: Do you know if there is anything wrong with his mind. They denied of any such thing in him and said: We do not know him but as a wise good man among us, so far as we can judge. He (Ma'iz) came for the third time, and he (the Holy Prophet) sent him as he had done before. He asked about him and they informed him that there was nothing wrong with him or with his mind. When it was the fourth time, a ditch was dug for him and he (the Holy Prophet) pronounced judg- ment about him and he wis stoned. He (the narrator) said: There came to him (the Holy Prophet) a woman from Ghamid and said: Allah's Messenger, I have committed adultery, so purify me. He (the Holy Prophet) turned her away. On the following day she said: Allah's Messenger, Why do you turn me away? Perhaps, you turn me away as you turned away Ma'iz. By Allah, I have become pregnant. He said: Well, if you insist upon it, then go away until you give birth to (the child). When she was delivered she came with the child (wrapped) in a rag and said: Here is the child whom I have given birth to. He said: Go away and suckle him until you wean him. When she had weaned him, she came to him (the Holy Prophet) with the child who was holding a piece of bread in his hand. She said: Allah's Apostle, here is he as I have weaned him and he eats food. He (the Holy Prophet) entrusted the child to one of the Muslims and then pronounced punishment. And she was put in a ditch up to her chest and he commanded people and they stoned her. Khalid b Walid came forward with a stone which he flung at her head and there spurted blood on the face of Khalid and so he abused her. Allah's Apostle (ﷺ) heard his (Khalid's) curse that he had huried upon her. Thereupon he (the Holy Prophet) said: Khalid, be gentle. By Him in Whose Hand is my life, she has made such a repentance that even if a wrongful tax-collector were to repent, he would have been forgiven. Then giving command regarding her, he prayed over her and she was buried}}
\hadithdefcmd{muslim}{4433}{حَدَّثَنِي أَبُو غَسَّانَ، مَالِكُ بْنُ عَبْدِ الْوَاحِدِ الْمِسْمَعِيُّ حَدَّثَنَا مُعَاذٌ، - يَعْنِي ابْنَ هِشَامٍ - حَدَّثَنِي أَبِي، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، حَدَّثَنِي أَبُو قِلاَبَةَ، أَنَّ أَبَا الْمُهَلَّبِ، حَدَّثَهُ عَنْ عِمْرَانَ، بْنِ حُصَيْنٍ أَنَّ امْرَأَةً، مِنْ جُهَيْنَةَ أَتَتْ نَبِيَّ اللَّهِ صلى الله عليه وسلم وَهِيَ حُبْلَى مِنَ الزِّنَى فَقَالَتْ يَا نَبِيَّ اللَّهِ أَصَبْتُ حَدًّا فَأَقِمْهُ عَلَىَّ فَدَعَا نَبِيُّ اللَّهِ صلى الله عليه وسلم وَلِيَّهَا فَقَالَ ‏"‏ أَحْسِنْ إِلَيْهَا فَإِذَا وَضَعَتْ فَائْتِنِي بِهَا ‏"‏ ‏.‏ فَفَعَلَ فَأَمَرَ بِهَا نَبِيُّ اللَّهِ صلى الله عليه وسلم فَشُكَّتْ عَلَيْهَا ثِيَابُهَا ثُمَّ أَمَرَ بِهَا فَرُجِمَتْ ثُمَّ صَلَّى عَلَيْهَا فَقَالَ لَهُ عُمَرُ تُصَلِّي عَلَيْهَا يَا نَبِيَّ اللَّهِ وَقَدْ زَنَتْ فَقَالَ ‏"‏ لَقَدْ تَابَتْ تَوْبَةً لَوْ قُسِمَتْ بَيْنَ سَبْعِينَ مِنْ أَهْلِ الْمَدِينَةِ لَوَسِعَتْهُمْ وَهَلْ وَجَدْتَ تَوْبَةً أَفْضَلَ مِنْ أَنْ جَادَتْ بِنَفْسِهَا لِلَّهِ تَعَالَى ‏"‏ ‏.‏\hadithno{4433}\hadithtrans{Imran b. Husain reported that a woman from Juhaina came to Allah's Apostle (ﷺ) and she had become pregnant because of adultery. She said:Allah's Apostle, I have done something for which (prescribed punishment) must be imposed upon me, so impose that. Allah's Apostle (ﷺ) called her master and said: Treat her well, and when she delivers bring her to me. He did accordingly. Then Allah's Apostle (ﷺ) pronounced judgment about her and her clothes were tied around her and then he commanded and she was stoned to death. He then prayed over her (dead body). Thereupon Umar said to him: Allah's Apostle, you offer prayer for her, whereas she had committed adultery! Thereupon he said: She has made such a repentance that if it were to be divided among seventy men of Medina, it would be enough. Have you found any repentance better than this that she sacr ficed her life for Allah, the Majestic?}}
\hadithdefcmd{muslim}{4434}{وَحَدَّثَنَاهُ أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَفَّانُ بْنُ مُسْلِمٍ، حَدَّثَنَا أَبَانٌ الْعَطَّارُ، حَدَّثَنَا يَحْيَى بْنُ أَبِي كَثِيرٍ، بِهَذَا الإِسْنَادِ مِثْلَهُ ‏.‏\hadithno{4434}\hadithtrans{This hadith has been transmitted on the authority of Yahya b. Abu Kathir}}
\hadithdefcmd{muslim}{4437}{حَدَّثَنِي الْحَكَمُ بْنُ مُوسَى أَبُو صَالِحٍ، حَدَّثَنَا شُعَيْبُ بْنُ إِسْحَاقَ، أَخْبَرَنَا عُبَيْدُ اللَّهِ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، أَخْبَرَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أُتِيَ بِيَهُودِيٍّ وَيَهُودِيَّةٍ قَدْ زَنَيَا فَانْطَلَقَ رَسُولُ اللَّهِ صلى الله عليه وسلم حَتَّى جَاءَ يَهُودَ فَقَالَ ‏"‏ مَا تَجِدُونَ فِي التَّوْرَاةِ عَلَى مَنْ زَنَى ‏"‏ ‏.‏ قَالُوا نُسَوِّدُ وُجُوهَهُمَا وَنُحَمِّلُهُمَا وَنُخَالِفُ بَيْنَ وُجُوهِهِمَا وَيُطَافُ بِهِمَا ‏.‏ قَالَ ‏"‏ فَأْتُوا بِالتَّوْرَاةِ إِنْ كُنْتُمْ صَادِقِينَ ‏"‏ ‏.‏ فَجَاءُوا بِهَا فَقَرَءُوهَا حَتَّى إِذَا مَرُّوا بِآيَةِ الرَّجْمِ وَضَعَ الْفَتَى الَّذِي يَقْرَأُ يَدَهُ عَلَى آيَةِ الرَّجْمِ وَقَرَأَ مَا بَيْنَ يَدَيْهَا وَمَا وَرَاءَهَا فَقَالَ لَهُ عَبْدُ اللَّهِ بْنُ سَلاَمٍ وَهْوَ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم مُرْهُ فَلْيَرْفَعْ يَدَهُ فَرَفَعَهَا فَإِذَا تَحْتَهَا آيَةُ الرَّجْمِ فَأَمَرَ بِهِمَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَرُجِمَا ‏.‏ قَالَ عَبْدُ اللَّهِ بْنُ عُمَرَ كُنْتُ فِيمَنْ رَجَمَهُمَا فَلَقَدْ رَأَيْتُهُ يَقِيهَا مِنَ الْحِجَارَةِ بِنَفْسِهِ ‏.‏\hadithno{4437}\hadithtrans{Abdullah b. 'Umar reported that a Jew and a Jewess were brought to Allah's Messenger (ﷺ) who had committed adultery. Allah's Messenger (ﷺ) came to the Jews and said:What do you find in Torah for one who commits adultery? They said: We darken their faces and make them ride on the donkey with their faces turned to the opposite direction (and their backs touching each other), and then they are taken round (the city). He said: Bring Torah if you are truthful. They brought it and recited it until when they came to the verse pertaining to stoning, the person who was reading placed his hand on the verse pertaining to stoning, and read (only that which was) between his hands and what was subsequent to that. Abdullah b. Salim who was at that time with the Messenger of Allah (ﷺ) said: Command him (the reciter) to lift his hand. He lifted it and there was, underneath that, the verse pertaining to stoning. Allah's Messenger (ﷺ) pronounced judgment about both of them and they were stoned. Abdullah b. 'Umar said: I was one of those who stoned them, and I saw him (the Jew) protecting her (the Jewess) with his body}}
\hadithdefcmd{muslim}{4438}{وَحَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا إِسْمَاعِيلُ، - يَعْنِي ابْنَ عُلَيَّةَ - عَنْ أَيُّوبَ، ح وَحَدَّثَنِي أَبُو الطَّاهِرِ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي رِجَالٌ، مِنْ أَهْلِ الْعِلْمِ مِنْهُمْ مَالِكُ بْنُ أَنَسٍ أَنَّ نَافِعًا، أَخْبَرَهُمْ عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم رَجَمَ فِي الزِّنَى يَهُودِيَّيْنِ رَجُلاً وَامْرَأَةً زَنَيَا فَأَتَتِ الْيَهُودُ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم بِهِمَا ‏.‏ وَسَاقُوا الْحَدِيثَ بِنَحْوِهِ ‏.‏\hadithno{4438}\hadithtrans{Ibn Umar reported that Allah's Messenger (ﷺ) stoned to death the Jews, both male and female, who had committed adultery. The Jews brought them to Allah's Messenger (may peace he upon him). The rest of the hadith is the same}}
\hadithdefcmd{muslim}{4439}{وَحَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا مُوسَى بْنُ عُقْبَةَ، عَنْ نَافِعٍ، عَنِ ابْنِ، عُمَرَ أَنَّ الْيَهُودَ، جَاءُوا إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم بِرَجُلٍ مِنْهُمْ وَامْرَأَةٍ قَدْ زَنَيَا ‏.‏ وَسَاقَ الْحَدِيثَ بِنَحْوِ حَدِيثِ عُبَيْدِ اللَّهِ عَنْ نَافِعٍ ‏.‏\hadithno{4439}\hadithtrans{Ibn 'Umar reported that the Jews brought to Allah's Messenger (ﷺ) a man and a woman who had committed adultery. The rest of the hadith is the same}}
\hadithdefcmd{muslim}{4440}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ كِلاَهُمَا عَنْ أَبِي مُعَاوِيَةَ، قَالَ يَحْيَى أَخْبَرَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ عَبْدِ اللَّهِ بْنِ مُرَّةَ، عَنِ الْبَرَاءِ بْنِ عَازِبٍ، قَالَ مُرَّ عَلَى النَّبِيِّ صلى الله عليه وسلم بِيَهُودِيٍّ مُحَمَّمًا مَجْلُودًا فَدَعَاهُمْ صلى الله عليه وسلم فَقَالَ ‏"‏ هَكَذَا تَجِدُونَ حَدَّ الزَّانِي فِي كِتَابِكُمْ ‏"‏ ‏.‏ قَالُوا نَعَمْ ‏.‏ فَدَعَا رَجُلاً مِنْ عُلَمَائِهِمْ فَقَالَ ‏"‏ أَنْشُدُكَ بِاللَّهِ الَّذِي أَنْزَلَ التَّوْرَاةَ عَلَى مُوسَى أَهَكَذَا تَجِدُونَ حَدَّ الزَّانِي فِي كِتَابِكُمْ ‏"‏ ‏.‏ قَالَ لاَ وَلَوْلاَ أَنَّكَ نَشَدْتَنِي بِهَذَا لَمْ أُخْبِرْكَ نَجِدُهُ الرَّجْمَ وَلَكِنَّهُ كَثُرَ فِي أَشْرَافِنَا فَكُنَّا إِذَا أَخَذْنَا الشَّرِيفَ تَرَكْنَاهُ وَإِذَا أَخَذْنَا الضَّعِيفَ أَقَمْنَا عَلَيْهِ الْحَدَّ قُلْنَا تَعَالَوْا فَلْنَجْتَمِعْ عَلَى شَىْءٍ نُقِيمُهُ عَلَى الشَّرِيفِ وَالْوَضِيعِ فَجَعَلْنَا التَّحْمِيمَ وَالْجَلْدَ مَكَانَ الرَّجْمِ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ اللَّهُمَّ إِنِّي أَوَّلُ مَنْ أَحْيَا أَمْرَكَ إِذْ أَمَاتُوهُ ‏"‏ ‏.‏ فَأَمَرَ بِهِ فَرُجِمَ فَأَنْزَلَ اللَّهُ عَزَّ وَجَلَّ ‏\{‏ يَا أَيُّهَا الرَّسُولُ لاَ يَحْزُنْكَ الَّذِينَ يُسَارِعُونَ فِي الْكُفْرِ‏\}‏ إِلَى قَوْلِهِ ‏\{‏ إِنْ أُوتِيتُمْ هَذَا فَخُذُوهُ‏\}‏ يَقُولُ ائْتُوا مُحَمَّدًا صلى الله عليه وسلم فَإِنْ أَمَرَكُمْ بِالتَّحْمِيمِ وَالْجَلْدِ فَخُذُوهُ وَإِنْ أَفْتَاكُمْ بِالرَّجْمِ فَاحْذَرُوا ‏.‏ فَأَنْزَلَ اللَّهُ تَعَالَى ‏\{‏ وَمَنْ لَمْ يَحْكُمْ بِمَا أَنْزَلَ اللَّهُ فَأُولَئِكَ هُمُ الْكَافِرُونَ‏\}‏ ‏\{‏ وَمَنْ لَمْ يَحْكُمْ بِمَا أَنْزَلَ اللَّهُ فَأُولَئِكَ هُمُ الظَّالِمُونَ‏\}‏ ‏\{‏ وَمَنْ لَمْ يَحْكُمْ بِمَا أَنْزَلَ اللَّهُ فَأُولَئِكَ هُمُ الْفَاسِقُونَ‏\}‏ فِي الْكُفَّارِ كُلُّهَا ‏.‏\hadithno{4440}\hadithtrans{Al-Bara' b. 'Azib reported:There happened to pass by Allah's Apostle (ﷺ) a Jew blackened and lashed. Allah's Apostle (ﷺ) called them (the Jews) and said: Is this the punishment that you find in your Book (Torah) as a prescribed punishment for adultery? They said: Yes. He (the Holy Prophet) called one of the scholars amongst them and said: I ask you in the name of Allah Who sent down the Torah on Moses if that is the prescribed punishment for adultery that you find in your Book. He said: No. Had you not asked me in the name of Allah, I would not have given you this information. We find stoning to death (as punishment prescribed in the Torah). But this (crime) became quite common amongst our aristocratic class. So when we caught hold of any rich person (indulging in this offence) we spared him, but when we caught hold of a helpless person we imposed the prescribed punishment upon him. We then said: Let us argree (on a punishment) which we can inflict both upon the rich and the poor. So We decided to blacken the face with coal and flog as a substitute punishment for stoning. Thereupon Allah's Messenger (ﷺ) said: O Allah, I am the first to revive Thy command when they had made it dead. He then commanded and he (the offender) was stoned to death. Allah, the Majestic and Glorious, sent down (this verse):" O Messenger, (the behaviour of) those who vie with one another in denying the truth should not grieve you..." up to" is vouchsafed unto you, accept it" (v. 41) 2176 It was said (by the Jews): Go to Muhammad; it he commands you to blacken the face and award flogging (as punishment for adultery), then accept it, but it he gives verdict for stoning, then avoid it. It was (then) that Allah, the Majestic and Great, sent down (these verses):" And they who do not judge in accordance with what Allah has revealed are, indeed, deniers of the truth" (v. 44) ;" And they who do not judge in accordance with what Allah has revealed-they, they indeed are the wrongdoers" (v. 45) ;" And they who do not judge in accordance with what God has revealed-they are the iniquitous (v. 47). (All these verses) were revealed in connection with the non-believers}}
\hadithdefcmd{muslim}{4441}{حَدَّثَنَا ابْنُ نُمَيْرٍ، وَأَبُو سَعِيدٍ الأَشَجُّ قَالاَ حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا الأَعْمَشُ، بِهَذَا الإِسْنَادِ ‏.‏ نَحْوَهُ إِلَى قَوْلِهِ فَأَمَرَ بِهِ النَّبِيُّ صلى الله عليه وسلم فَرُجِمَ ‏.‏ وَلَمْ يَذْكُرْ مَا بَعْدَهُ مِنْ نُزُولِ الآيَةِ ‏.‏\hadithno{4441}\hadithtrans{This hadith has been narrated on the authority of A'mash up to the words:" Allah's Apostle (ﷺ) pronounced judgment and he was stoned (to death)" And he mentioned nothing subsequent to that pertaining to the revelation of verses}}
\hadithdefcmd{muslim}{4442}{وَحَدَّثَنِي هَارُونُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا حَجَّاجُ بْنُ مُحَمَّدٍ، قَالَ قَالَ ابْنُ جُرَيْجٍ أَخْبَرَنِي أَبُو الزُّبَيْرِ، أَنَّهُ سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ، يَقُولُ رَجَمَ النَّبِيُّ صلى الله عليه وسلم رَجُلاً مِنْ أَسْلَمَ وَرَجُلاً مِنَ الْيَهُودِ وَامْرَأَتَهُ ‏.‏\hadithno{4442}\hadithtrans{Jabir b. 'Abdullah reported that Allah's Apostle (ﷺ) stoned (to death) a person from Banu Aslam, and a Jew and his wife}}
\hadithdefcmd{muslim}{4443}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا رَوْحُ بْنُ عُبَادَةَ، حَدَّثَنَا ابْنُ جُرَيْجٍ، بِهَذَا الإِسْنَادِ مِثْلَهُ ‏.‏ غَيْرَ أَنَّهُ قَالَ وَامْرَأَةً ‏.‏\hadithno{4443}\hadithtrans{This hadith has been transmitted on the authority of Juraij with a slight variation of words}}
\hadithdefcmd{muslim}{4444}{وَحَدَّثَنَا أَبُو كَامِلٍ الْجَحْدَرِيُّ، حَدَّثَنَا عَبْدُ الْوَاحِدِ، حَدَّثَنَا سُلَيْمَانُ الشَّيْبَانِيُّ، قَالَ سَأَلْتُ عَبْدَ اللَّهِ بْنَ أَبِي أَوْفَى ح. وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، - وَاللَّفْظُ لَهُ - حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنْ أَبِي، إِسْحَاقَ الشَّيْبَانِيِّ قَالَ سَأَلْتُ عَبْدَ اللَّهِ بْنَ أَبِي أَوْفَى هَلْ رَجَمَ رَسُولُ اللَّهِ صلى الله عليه وسلم قَالَ نَعَمْ ‏.‏ قَالَ قُلْتُ بَعْدَ مَا أُنْزِلَتْ سُورَةُ النُّورِ أَمْ قَبْلَهَا قَالَ لاَ أَدْرِي ‏.‏\hadithno{4444}\hadithtrans{Abu Ishaq Shaibani said:I asked 'Abdullah b. Abu Aufi if Allah's Messenger (ﷺ) awarded (the punishment) of stoning (to death). He said: Yes. I said: After Sura al-Nur was revealed or before that? He said: I do not know}}
\hadithdefcmd{muslim}{4445}{وَحَدَّثَنِي عِيسَى بْنُ حَمَّادٍ الْمِصْرِيُّ، أَخْبَرَنَا اللَّيْثُ، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّهُ سَمِعَهُ يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِذَا زَنَتْ أَمَةُ أَحَدِكُمْ فَتَبَيَّنَ زِنَاهَا فَلْيَجْلِدْهَا الْحَدَّ وَلاَ يُثَرِّبْ عَلَيْهَا ثُمَّ إِنْ زَنَتْ فَلْيَجْلِدْهَا الْحَدَّ وَلاَ يُثَرِّبْ عَلَيْهَا ثُمَّ إِنْ زَنَتِ الثَّالِثَةَ فَتَبَيَّنَ زِنَاهَا فَلْيَبِعْهَا وَلَوْ بِحَبْلٍ مِنْ شَعَرٍ ‏"‏ ‏.‏\hadithno{4445}\hadithtrans{Abu Huraira reported that he heard Allah's Messenger (ﷺ) as saying:When the slave-woman of any of you commits adultery and this (offence of hers) becomes clear, she should be flogged (as the prescribed) punishment, but hurl no reproach at her. If she commits adultery again, she should (again be punished) by flogging, but hurl no reproach upon her. If she commits fornication for the third time and it becomes clear, then he should sell her, even if only for a rope of hair}}
\hadithdefcmd{muslim}{4446}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، جَمِيعًا عَنِ ابْنِ عُيَيْنَةَ، ح وَحَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، أَخْبَرَنَا مُحَمَّدُ بْنُ بَكْرٍ الْبُرْسَانِيُّ، أَخْبَرَنَا هِشَامُ بْنُ حَسَّانَ، كِلاَهُمَا عَنْ أَيُّوبَ بْنِ مُوسَى، ح وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو أُسَامَةَ، وَابْنُ، نُمَيْرٍ عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، ح وَحَدَّثَنِي هَارُونُ بْنُ سَعِيدٍ الأَيْلِيُّ، حَدَّثَنَا ابْنُ وَهْبٍ، حَدَّثَنِي أُسَامَةُ، بْنُ زَيْدٍ ح وَحَدَّثَنَا هَنَّادُ بْنُ السَّرِيِّ، وَأَبُو كُرَيْبٍ وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ عَنْ عَبْدَةَ بْنِ سُلَيْمَانَ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، كُلُّ هَؤُلاَءِ عَنْ سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم إِلاَّ أَنَّ ابْنَ إِسْحَاقَ قَالَ فِي حَدِيثِهِ عَنْ سَعِيدٍ عَنْ أَبِيهِ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم فِي جَلْدِ الأَمَةِ إِذَا زَنَتْ ثَلاَثًا ‏ "‏ ثُمَّ لْيَبِعْهَا فِي الرَّابِعَةِ ‏"‏ ‏.‏\hadithno{4446}\hadithtrans{This hadith his been narrated on the authority of Abu Huraira through another chain of transmitters with a slight variation of words}}
\hadithdefcmd{muslim}{4447}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ الْقَعْنَبِيُّ، حَدَّثَنَا مَالِكٌ، ح وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، - وَاللَّفْظُ لَهُ - قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنِ ابْنِ شِهَابٍ عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ عَنْ أَبِي هُرَيْرَةَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم سُئِلَ عَنِ الأَمَةِ إِذَا زَنَتْ وَلَمْ تُحْصِنْ قَالَ ‏ "‏ إِنْ زَنَتْ فَاجْلِدُوهَا ثُمَّ إِنْ زَنَتْ فَاجْلِدُوهَا ثُمَّ إِنْ زَنَتْ فَاجْلِدُوهَا ثُمَّ بِيعُوهَا وَلَوْ بِضَفِيرٍ ‏"‏ ‏.‏ قَالَ ابْنُ شِهَابٍ لاَ أَدْرِي أَبَعْدَ الثَّالِثَةِ أَوِ الرَّابِعَةِ ‏.‏ وَقَالَ الْقَعْنَبِيُّ فِي رِوَايَتِهِ قَالَ ابْنُ شِهَابٍ وَالضَّفِيرُ الْحَبْلُ ‏.‏\hadithno{4447}\hadithtrans{Abu Huraira reported that Allah's Messenger (ﷺ) was asked about the slave-woman who committed adultery and was not protected (married). He said:If she commits adultery, then flog her and if she commits adultery again, then flog her and then sell her even for a rope. Ibn Shihab said: I do not know whether he said this (his statement pertaining to the sale of slave-woman) at the third or the fourth time. Ibn Shihab said that the word dafir (used in the text) means rope}}
\hadithdefcmd{muslim}{4448}{وَحَدَّثَنَا أَبُو الطَّاهِرِ، أَخْبَرَنَا ابْنُ وَهْبٍ، قَالَ سَمِعْتُ مَالِكًا، يَقُولُ حَدَّثَنِي ابْنُ شِهَابٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، عَنْ أَبِي هُرَيْرَةَ، وَزَيْدِ بْنِ خَالِدٍ الْجُهَنِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم سُئِلَ عَنِ الأَمَةِ ‏.‏ بِمِثْلِ حَدِيثِهِمَا وَلَمْ يَذْكُرْ قَوْلَ ابْنِ شِهَابٍ وَالضَّفِيرُ الْحَبْلُ ‏.‏\hadithno{4448}\hadithtrans{This hadith has been narrated on the authority of Abu Huraira and Zaid b. Khalid al-Jubani, but in this no merition is made of the words of Ibn Shihab that dafir means rope}}
\hadithdefcmd{muslim}{4449}{حَدَّثَنِي عَمْرٌو النَّاقِدُ، حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ بْنِ سَعْدٍ، حَدَّثَنِي أَبِي، عَنْ صَالِحٍ، ح وَحَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، كِلاَهُمَا عَنِ الزُّهْرِيِّ، عَنْ عُبَيْدِ، اللَّهِ عَنْ أَبِي هُرَيْرَةَ، وَزَيْدِ بْنِ خَالِدٍ الْجُهَنِيِّ، عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ بِمِثْلِ حَدِيثِ مَالِكٍ وَالشَّكُّ فِي حَدِيثِهِمَا جَمِيعًا فِي بَيْعِهَا فِي الثَّالِثَةِ أَوِ الرَّابِعَةِ ‏.‏\hadithno{4449}\hadithtrans{This hadith has been transmitted on the authority of Abu Huraira and Zaid b. Khalid al-Juhani in the same way as transmitted by Malik with this (difference) tnat there is a doubt whether her sale (that of the slave-girl committing adultery) was mentioned after the third or the fourth time}}
\hadithdefcmd{muslim}{4450}{حَدَّثَنَا مُحَمَّدُ بْنُ أَبِي بَكْرٍ الْمُقَدَّمِيُّ، حَدَّثَنَا سُلَيْمَانُ أَبُو دَاوُدَ، حَدَّثَنَا زَائِدَةُ، عَنِ السُّدِّيِّ، عَنْ سَعْدِ بْنِ عُبَيْدَةَ، عَنْ أَبِي عَبْدِ الرَّحْمَنِ، قَالَ خَطَبَ عَلِيٌّ فَقَالَ يَا أَيُّهَا النَّاسُ أَقِيمُوا عَلَى أَرِقَّائِكُمُ الْحَدَّ مَنْ أَحْصَنَ مِنْهُمْ وَمَنْ لَمْ يُحْصِنْ فَإِنَّ أَمَةً لِرَسُولِ اللَّهِ صلى الله عليه وسلم زَنَتْ فَأَمَرَنِي أَنْ أَجْلِدَهَا فَإِذَا هِيَ حَدِيثُ عَهْدٍ بِنِفَاسٍ فَخَشِيتُ إِنْ أَنَا جَلَدْتُهَا أَنْ أَقْتُلَهَا فَذَكَرْتُ ذَلِكَ لِلنَّبِيِّ صلى الله عليه وسلم فَقَالَ ‏ "‏ أَحْسَنْتَ ‏"‏ ‏.‏\hadithno{4450}\hadithtrans{Abd al-Rahman reported that 'Ali, while delivering the address said:O people, impose the prescribed punishment upon your slaves, those who are married and those not married, for a slave-woman belonging to Allah's Messenger (ﷺ) had committed adultery, and he committed me to flog her. But she had recently given birth to a child and I was afraid that if I flogged her I might kill her. So I mentioned that to Allah's Apostle (ﷺ) and he said: You have done well}}
\hadithdefcmd{muslim}{4451}{وَحَدَّثَنَاهُ إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا يَحْيَى بْنُ آدَمَ، حَدَّثَنَا إِسْرَائِيلُ، عَنِ السُّدِّيِّ، بِهَذَا الإِسْنَادِ وَلَمْ يَذْكُرْ مَنْ أَحْصَنَ مِنْهُمْ وَمَنْ لَمْ يُحْصِنْ ‏.‏ وَزَادَ فِي الْحَدِيثِ ‏ "‏ اتْرُكْهَا حَتَّى تَمَاثَلَ ‏"‏ ‏.‏\hadithno{4451}\hadithtrans{This hadith has been narrated on the authority of as-Suddi with the same chain of trznsmitters, but he did not mention:" Those who are married and those who are not married." There is also an addition in it:" I spare her until she is all right}}
\hadithdefcmd{muslim}{4452}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَمُحَمَّدُ بْنُ بَشَّارٍ، قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، قَالَ سَمِعْتُ قَتَادَةَ، يُحَدِّثُ عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم أُتِيَ بِرَجُلٍ قَدْ شَرِبَ الْخَمْرَ فَجَلَدَهُ بِجَرِيدَتَيْنِ نَحْوَ أَرْبَعِينَ ‏.‏ قَالَ وَفَعَلَهُ أَبُو بَكْرٍ فَلَمَّا كَانَ عُمَرُ اسْتَشَارَ النَّاسَ فَقَالَ عَبْدُ الرَّحْمَنِ أَخَفَّ الْحُدُودِ ثَمَانِينَ ‏.‏ فَأَمَرَ بِهِ عُمَرُ ‏.‏\hadithno{4452}\hadithtrans{Anas b. Malik reported that a person who had drink wine was brought to Allah's Apostle (ﷺ). He gave him forty stripes with two lashes. Abu Bakr also did that, but when Umar (assumed the responsibilities) of the Caliphate, he consulted people and Abd al-Rahman said:The mildest punishment (for drinking) is eighty (stripes) and 'Umar their prescribed this punishment}}
\hadithdefcmd{muslim}{4453}{وَحَدَّثَنَا يَحْيَى بْنُ حَبِيبٍ الْحَارِثِيُّ، حَدَّثَنَا خَالِدٌ، - يَعْنِي ابْنَ الْحَارِثِ - حَدَّثَنَا شُعْبَةُ، حَدَّثَنَا قَتَادَةُ، قَالَ سَمِعْتُ أَنَسًا، يَقُولُ أُتِيَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِرَجُلٍ ‏.‏ فَذَكَرَ نَحْوَهُ ‏.‏\hadithno{4453}\hadithtrans{This hadith has been narrated on the authority of Anas through another chain of transmitters}}
\hadithdefcmd{muslim}{4454}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا مُعَاذُ بْنُ هِشَامٍ، حَدَّثَنِي أَبِي، عَنْ قَتَادَةَ، عَنْ أَنَسِ، بْنِ مَالِكٍ أَنَّ نَبِيَّ اللَّهِ صلى الله عليه وسلم جَلَدَ فِي الْخَمْرِ بِالْجَرِيدِ وَالنِّعَالِ ثُمَّ جَلَدَ أَبُو بَكْرٍ أَرْبَعِينَ ‏.‏ فَلَمَّا كَانَ عُمَرُ وَدَنَا النَّاسُ مِنَ الرِّيفِ وَالْقُرَى قَالَ مَا تَرَوْنَ فِي جَلْدِ الْخَمْرِ فَقَالَ عَبْدُ الرَّحْمَنِ بْنُ عَوْفٍ أَرَى أَنْ تَجْعَلَهَا كَأَخَفِّ الْحُدُودِ ‏.‏ قَالَ فَجَلَدَ عُمَرُ ثَمَانِينَ ‏.‏\hadithno{4454}\hadithtrans{Anas b. Malik reported that Allah's Apostle (ﷺ) gave a beating with palm branches and shoes, and that Abu Bakr gave forty lashes. When Umar (became the Commander of the Faithful) and the people went near to pastures and towns, he said (to the Companions of the Holy Prophet). What is your opinion about lashing for drinking? Thereupon Abd al-Rahman b. Auf said:My opinion is that you fix it as the mildest punishment. Then 'Umar inflicted eighty stripes}}
\hadithdefcmd{muslim}{4455}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، حَدَّثَنَا هِشَامٌ، بِهَذَا الإِسْنَادِ مِثْلَهُ\hadithno{4455}\hadithtrans{This hadith has been narrated on the authority of Hisham with the same chain of transmitters}}
\hadithdefcmd{muslim}{4456}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، عَنْ هِشَامٍ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، أَنَّوسلم كَانَ يَضْرِبُ فِي الْخَمْرِ بِالنِّعَالِ وَالْجَرِيدِ أَرْبَعِينَ ‏.‏ ثُمَّ ذَكَرَ نَحْوَ حَدِيثِهِمَا وَلَمْ يَذْكُرِ الرِّيفَ وَالْقُرَى ‏.‏\hadithno{4456}\hadithtrans{Anas reported that Allah's Apostle (ﷺ) used to strike forty times with shoes and palm branches (in case of drinking of) wine. The rest of the hadith is the same and there is no mention of pastures and towns}}
\hadithdefcmd{muslim}{4457}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَزُهَيْرُ بْنُ حَرْبٍ، وَعَلِيُّ بْنُ حُجْرٍ، قَالُوا حَدَّثَنَا إِسْمَاعِيلُ، - وَهُوَ ابْنُ عُلَيَّةَ - عَنِ ابْنِ أَبِي عَرُوبَةَ، عَنْ عَبْدِ اللَّهِ الدَّانَاجِ، ح وَحَدَّثَنَا إِسْحَاقُ، بْنُ إِبْرَاهِيمَ الْحَنْظَلِيُّ - وَاللَّفْظُ لَهُ - أَخْبَرَنَا يَحْيَى بْنُ حَمَّادٍ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ الْمُخْتَارِ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ فَيْرُوزَ، مَوْلَى ابْنِ عَامِرٍ الدَّانَاجِ حَدَّثَنَا حُضَيْنُ بْنُ الْمُنْذِرِ أَبُو سَاسَانَ، قَالَ شَهِدْتُ عُثْمَانَ بْنَ عَفَّانَ وَأُتِيَ بِالْوَلِيدِ قَدْ صَلَّى الصُّبْحَ رَكْعَتَيْنِ ثُمَّ قَالَ أَزِيدُكُمْ فَشَهِدَ عَلَيْهِ رَجُلاَنِ أَحَدُهُمَا حُمْرَانُ أَنَّهُ شَرِبَ الْخَمْرَ وَشَهِدَ آخَرُ أَنَّهُ رَآهُ يَتَقَيَّأُ فَقَالَ عُثْمَانُ إِنَّهُ لَمْ يَتَقَيَّأْ حَتَّى شَرِبَهَا فَقَالَ يَا عَلِيُّ قُمْ فَاجْلِدْهُ ‏.‏ فَقَالَ عَلِيٌّ قُمْ يَا حَسَنُ فَاجْلِدْهُ ‏.‏ فَقَالَ الْحَسَنُ وَلِّ حَارَّهَا مَنْ تَوَلَّى قَارَّهَا - فَكَأَنَّهُ وَجَدَ عَلَيْهِ - فَقَالَ يَا عَبْدَ اللَّهِ بْنَ جَعْفَرٍ قُمْ فَاجْلِدْهُ ‏.‏ فَجَلَدَهُ وَعَلِيٌّ يَعُدُّ حَتَّى بَلَغَ أَرْبَعِينَ فَقَالَ أَمْسِكْ ‏.‏ ثُمَّ قَالَ جَلَدَ النَّبِيُّ صلى الله عليه وسلم أَرْبَعِينَ وَجَلَدَ أَبُو بَكْرٍ أَرْبَعِينَ وَعُمَرُ ثَمَانِينَ وَكُلٌّ سُنَّةٌ وَهَذَا أَحَبُّ إِلَىَّ ‏.‏ زَادَ عَلِيُّ بْنُ حُجْرٍ فِي رِوَايَتِهِ قَالَ إِسْمَاعِيلُ وَقَدْ سَمِعْتُ حَدِيثَ الدَّانَاجِ مِنْهُ فَلَمْ أَحْفَظْهُ ‏.‏\hadithno{4457}\hadithtrans{Hudain b. al-Mundhir Abu Sasan reported:I saw that Walid was brought to Uthmin b. 'Affan as he had prayed two rak'ahs of the dawn prayer, and then he said: I make an increase for you. And two men bore witness against him. One of them was Humran who said that he had drunk wine. The second one gave witness that he had seen him vomiting. Uthman said: He would not have vomited (wine) unless he had drunk it. He said: 'Ali, stand up and lash him. 'Ali said: Hasan, stand up and lash him. Thereupon Hasan said: Let him suffer the heat (of Caliphate) who has enjoyed its coolness. ('Ali felt annoyed at this remark) and he said: 'Abdullah b. Ja'far, stand up and flog him, and he began to flog him and 'Ali counted the stripes until these were forty. He (Hadrat 'Ali) said: Stop now, and then said: Allah's Apostle (ﷺ) gave forty stripes, and Abu Bakr also gave forty stripes, and Umar gave eighty stripes, and all these fall under the category of the Sunnab, but this one (forty stripes) is dearer to me}}
\hadithdefcmd{muslim}{4458}{حَدَّثَنِي مُحَمَّدُ بْنُ مِنْهَالٍ الضَّرِيرُ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا سُفْيَانُ الثَّوْرِيُّ، عَنْ أَبِي حَصِينٍ، عَنْ عُمَيْرِ بْنِ سَعِيدٍ، عَنْ عَلِيٍّ، قَالَ مَا كُنْتُ أُقِيمُ عَلَى أَحَدٍ حَدًّا فَيَمُوتَ فِيهِ فَأَجِدَ مِنْهُ فِي نَفْسِي إِلاَّ صَاحِبَ الْخَمْرِ لأَنَّهُ إِنْ مَاتَ وَدَيْتُهُ لأَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم لَمْ يَسُنَّهُ ‏.‏\hadithno{4458}\hadithtrans{Ali reported:If I impose Hadd on anyone, and he (in course of punish ment) dies, I would not mind except in case of a drunkard. If he dies. I would pay indemnity for him because the Messenger of Allah (ﷺ) has laid down no rule for it}}
\hadithdefcmd{muslim}{4459}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الرَّحْمَنِ، حَدَّثَنَا سُفْيَانُ، بِهَذَا الإِسْنَادِ مِثْلَهُ ‏.‏\hadithno{4459}\hadithtrans{This hadith is narrated on the authority of Sufyan}}
\hadithdefcmd{muslim}{4460}{حَدَّثَنَا أَحْمَدُ بْنُ عِيسَى، حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي عَمْرٌو، عَنْ بُكَيْرِ بْنِ الأَشَجِّ، قَالَ بَيْنَا نَحْنُ عِنْدَ سُلَيْمَانَ بْنِ يَسَارٍ إِذْ جَاءَهُ عَبْدُ الرَّحْمَنِ بْنُ جَابِرٍ فَحَدَّثَهُ فَأَقْبَلَ، عَلَيْنَا سُلَيْمَانُ فَقَالَ حَدَّثَنِي عَبْدُ الرَّحْمَنِ بْنُ جَابِرٍ، عَنْ أَبِيهِ، عَنْ أَبِي بُرْدَةَ الأَنْصَارِيِّ، أَنَّهُ سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ يُجْلَدُ أَحَدٌ فَوْقَ عَشَرَةِ أَسْوَاطٍ إِلاَّ فِي حَدٍّ مِنْ حُدُودِ اللَّهِ ‏"‏ ‏.‏\hadithno{4460}\hadithtrans{Abu Barda Ansari reported Allah's Messenger (ﷺ) as saying:None should be given more than ten lashes, but in case of any Hadd out of the Huded of Allah}}
\hadithdefcmd{muslim}{4461}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى التَّمِيمِيُّ، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ وَعَمْرٌو النَّاقِدُ وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ وَابْنُ نُمَيْرٍ كُلُّهُمْ عَنِ ابْنِ عُيَيْنَةَ، - وَاللَّفْظُ لِعَمْرٍو قَالَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي إِدْرِيسَ، عَنْ عُبَادَةَ بْنِ الصَّامِتِ، قَالَ كُنَّا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي مَجْلِسٍ فَقَالَ ‏ "‏ تُبَايِعُونِي عَلَى أَنْ لاَ تُشْرِكُوا بِاللَّهِ شَيْئًا وَلاَ تَزْنُوا وَلاَ تَسْرِقُوا وَلاَ تَقْتُلُوا النَّفْسَ الَّتِي حَرَّمَ اللَّهُ إِلاَّ بِالْحَقِّ فَمَنْ وَفَى مِنْكُمْ فَأَجْرُهُ عَلَى اللَّهِ وَمَنْ أَصَابَ شَيْئًا مِنْ ذَلِكَ فَعُوقِبَ بِهِ فَهُوَ كَفَّارَةٌ لَهُ وَمَنْ أَصَابَ شَيْئًا مِنْ ذَلِكَ فَسَتَرَهُ اللَّهُ عَلَيْهِ فَأَمْرُهُ إِلَى اللَّهِ إِنْ شَاءَ عَفَا عَنْهُ وَإِنْ شَاءَ عَذَّبَهُ ‏"‏ ‏.‏\hadithno{4461}\hadithtrans{Ubida b. as-Samit reported:While we were in the company of Allah's Messenger (may peace be upoi him) he said: Swear allegiance to me that you will not associate anything with Allah, that you will not commit adultery, that you will not steal, that you will not take any life which it is forbidden by Allah to take but with (legal) justification; and whoever among you fulfils it, his reward is with Allah and he who commits any such thing and is punished for it, that will be all atonement for it And if anyone commits anything and Allah conceals (his faultfls), his matter rests with Allah. He may forgive if He likes, and He may punish him if He likes}}
\hadithdefcmd{muslim}{4462}{حَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، بِهَذَا الإِسْنَادِ وَزَادَ فِي الْحَدِيثِ فَتَلاَ عَلَيْنَا آيَةَ النِّسَاءِ ‏\{‏ أَنْ لاَ يُشْرِكْنَ بِاللَّهِ شَيْئًا‏\}‏ الآيَةَ ‏.‏\hadithno{4462}\hadithtrans{This hadith has been narrated on the authority of Zuhri with the same chain of transmitters with this addition:" He recited to us the verse pertaining to women, viz, that they will not associate anything with Allah}}
\hadithdefcmd{muslim}{4463}{وَحَدَّثَنِي إِسْمَاعِيلُ بْنُ سَالِمٍ، أَخْبَرَنَا هُشَيْمٌ، أَخْبَرَنَا خَالِدٌ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَبِي الأَشْعَثِ الصَّنْعَانِيِّ، عَنْ عُبَادَةَ بْنِ الصَّامِتِ، قَالَ أَخَذَ عَلَيْنَا رَسُولُ اللَّهِ صلى الله عليه وسلم كَمَا أَخَذَ عَلَى النِّسَاءِ أَنْ لاَ نُشْرِكَ بِاللَّهِ شَيْئًا وَلاَ نَسْرِقَ وَلاَ نَزْنِيَ وَلاَ نَقْتُلَ أَوْلاَدَنَا وَلاَ يَعْضَهَ بَعْضُنَا بَعْضًا ‏ "‏ فَمَنْ وَفَى مِنْكُمْ فَأَجْرُهُ عَلَى اللَّهِ وَمَنْ أَتَى مِنْكُمْ حَدًّا فَأُقِيمَ عَلَيْهِ فَهُوَ كَفَّارَتُهُ وَمَنْ سَتَرَهُ اللَّهُ عَلَيْهِ فَأَمْرُهُ إِلَى اللَّهِ إِنْ شَاءَ عَذَّبَهُ وَإِنْ شَاءَ غَفَرَ لَهُ ‏"‏ ‏.‏\hadithno{4463}\hadithtrans{Ubida b. as-Samit reported:Allah's Messenger (ﷺ) took (a pledge) from us as he took from the women that we will not associate anything with Allah and we will not steal, and we will not commit adultery, and we will not kill our children, and we will not bring calumny upon one another. And he who amongst you fulfils (this pledge), his reward rests with Allah, and he upon whom amongst you is imposed the prescribed punishment and that is carried out, that is his expiation (for that sin), and he whose (sins) were covered by Allah, his matter rests with Allah. He may punish him if He likes or may forgive him if He so likes}}
\hadithdefcmd{muslim}{4464}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، أَخْبَرَنَا اللَّيْثُ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ أَبِي الْخَيْرِ، عَنِ الصُّنَابِحِيِّ، عَنْ عُبَادَةَ بْنِ الصَّامِتِ، أَنَّهُ قَالَ إِنِّي لَمِنَ النُّقَبَاءِ الَّذِينَ بَايَعُوا رَسُولَ اللَّهِ صلى الله عليه وسلم وَقَالَ بَايَعْنَاهُ عَلَى أَنْ لاَ نُشْرِكَ بِاللَّهِ شَيْئًا وَلاَ نَزْنِيَ وَلاَ نَسْرِقَ وَلاَ نَقْتُلَ النَّفْسَ الَّتِي حَرَّمَ اللَّهُ إِلاَّ بِالْحَقِّ وَلاَ نَنْتَهِبَ وَلاَ نَعْصِيَ فَالْجَنَّةُ إِنْ فَعَلْنَا ذَلِكَ فَإِنْ غَشِينَا مِنْ ذَلِكَ شَيْئًا كَانَ قَضَاءُ ذَلِكَ إِلَى اللَّهِ ‏.‏ وَقَالَ ابْنُ رُمْحٍ كَانَ قَضَاؤُهُ إِلَى اللَّهِ ‏.‏\hadithno{4464}\hadithtrans{Ubida b. as-Samit repnrted:I was one of those headmen who swore allegiance to Allah's Messenger (ﷺ) that we will not associate anything with Allah, and will not commit adultery, and will not steal, and will not kill any soul which Allah has forbidden, but with justice nor plunder, nor disobey (Allah and His Apostle), then Paradise (will be the reward) in case we do these (acts) ; and if we commit any outrage (and that goes unpunished in the world), it is Allah Who would decide about it. Ibn Rumh said: Its judgment lies with Allah}}
\hadithdefcmd{muslim}{4465}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَمُحَمَّدُ بْنُ رُمْحٍ، قَالاَ أَخْبَرَنَا اللَّيْثُ، ح وَحَدَّثَنَا قُتَيْبَةُ بْنُ، سَعِيدٍ حَدَّثَنَا لَيْثٌ، عَنِ ابْنِ شِهَابٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، وَأَبِي، سَلَمَةَ عَنْ أَبِي هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ الْعَجْمَاءُ جَرْحُهَا جُبَارٌ وَالْبِئْرُ جُبَارٌ وَالْمَعْدِنُ جُبَارٌ وَفِي الرِّكَازِ الْخُمْسُ ‏"‏ ‏.‏\hadithno{4465}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:No requital is payable for a wound caused by an animal, for (falling into) a well and a mine, and one-fifth (is the share of the government) in the buried treasure (treasure-trove)}}
\hadithdefcmd{muslim}{4466}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ وَزُهَيْرُ بْنُ حَرْبٍ وَعَبْدُ الأَعْلَى بْنُ حَمَّادٍ كُلُّهُمْ عَنِ ابْنِ عُيَيْنَةَ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا إِسْحَاقُ، - يَعْنِي ابْنَ عِيسَى - حَدَّثَنَا مَالِكٌ، كِلاَهُمَا عَنِ الزُّهْرِيِّ، بِإِسْنَادِ اللَّيْثِ ‏.‏ مِثْلَ حَدِيثِهِ ‏.‏\hadithno{4466}\hadithtrans{A hadith like this has been transmitted on the authority of Zuhri}}
\hadithdefcmd{muslim}{4467}{وَحَدَّثَنِي أَبُو الطَّاهِرِ، وَحَرْمَلَةُ، قَالاَ أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ، شِهَابٍ عَنِ ابْنِ الْمُسَيَّبِ، وَعُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِي هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم بِمِثْلِهِ ‏.‏\hadithno{4467}\hadithtrans{A hadith like this has been transmitted on the authority of Abu Huraira}}
\hadithdefcmd{muslim}{4468}{حَدَّثَنَا مُحَمَّدُ بْنُ رُمْحِ بْنِ الْمُهَاجِرِ، أَخْبَرَنَا اللَّيْثُ، عَنْ أَيُّوبَ بْنِ مُوسَى، عَنِ الأَسْوَدِ، بْنِ الْعَلاَءِ عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ الْبِئْرُ جَرْحُهَا جُبَارٌ وَالْمَعْدِنُ جَرْحُهُ جُبَارٌ وَالْعَجْمَاءُ جَرْحُهَا جُبَارٌ وَفِي الرِّكَازِ الْخُمْسُ ‏"‏ ‏.‏\hadithno{4468}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:The wound caused (by falling) in the well, in the mine, and caused bv the animal has no requital for it; and there is one-fifth (for the government) in the buried treasure}}
\hadithdefcmd{muslim}{4469}{وَحَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ سَلاَّمٍ الْجُمَحِيُّ، حَدَّثَنَا الرَّبِيعُ يَعْنِي ابْنَ مُسْلِمٍ، ح وَحَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي ح، وَحَدَّثَنَا ابْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، قَالاَ حَدَّثَنَا شُعْبَةُ، كِلاَهُمَا عَنْ مُحَمَّدِ بْنِ زِيَادٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِهِ ‏.‏\hadithno{4469}\hadithtrans{A hadith like this has been transmitted on the authority of Abu Huraira}}
